@@ -4,6 +4,7 @@ from datetime import datetime
 import pandas as pd
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.client import get_client, staticproperty
 from datarobot.enums import (
     CV_METHOD,
@@ -388,7 +389,7 @@ def construct_duration_string(years=0, months=0, days=0, hours=0, minutes=0, sec
 
 _periodicity_converter = t.Dict(
     {
-        t.Key("time_steps"): t.Int(gte=0, lte=PERIODICITY_MAX_TIME_STEP),
+        t.Key("time_steps"): Int(gte=0, lte=PERIODICITY_MAX_TIME_STEP),
         t.Key("time_unit"): t.Enum(
             TIME_UNITS.MILLISECOND,
             TIME_UNITS.SECOND,
@@ -445,7 +446,7 @@ class Periodicity(object):
 
 _feature_settings_converter = t.Dict(
     {
-        t.Key("feature_name"): t.String(),
+        t.Key("feature_name"): String(),
         t.Key("known_in_advance", optional=True, default=None): t.Bool() | t.Null,
         t.Key("do_not_derive", optional=True, default=None): t.Bool() | t.Null,
     }
@@ -510,24 +511,24 @@ class FeatureSettings(object):
 
 _backtest_converter = t.Dict(
     {
-        t.Key("index"): t.Int(),
+        t.Key("index"): Int(),
         t.Key("available_training_start_date"): parse_time,
-        t.Key("available_training_duration"): t.String(),
-        t.Key("available_training_row_count", optional=True): t.Int(),
+        t.Key("available_training_duration"): String(),
+        t.Key("available_training_row_count", optional=True): Int(),
         t.Key("available_training_end_date"): parse_time,
         t.Key("primary_training_start_date"): parse_time,
-        t.Key("primary_training_duration"): t.String(),
-        t.Key("primary_training_row_count", optional=True): t.Int(),
+        t.Key("primary_training_duration"): String(),
+        t.Key("primary_training_row_count", optional=True): Int(),
         t.Key("primary_training_end_date"): parse_time,
         t.Key("gap_start_date"): parse_time,
-        t.Key("gap_duration"): t.String(),
-        t.Key("gap_row_count", optional=True): t.Int(),
+        t.Key("gap_duration"): String(),
+        t.Key("gap_row_count", optional=True): Int(),
         t.Key("gap_end_date"): parse_time,
         t.Key("validation_start_date"): parse_time,
-        t.Key("validation_duration"): t.String(),
-        t.Key("validation_row_count", optional=True): t.Int(),
+        t.Key("validation_duration"): String(),
+        t.Key("validation_row_count", optional=True): Int(),
         t.Key("validation_end_date"): parse_time,
-        t.Key("total_row_count", optional=True): t.Int(),
+        t.Key("total_row_count", optional=True): Int(),
     }
 ).ignore_extra("*")
 
@@ -1317,39 +1318,39 @@ class DatetimePartitioning(object):
     _client = staticproperty(get_client)
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String(),
-            t.Key("datetime_partition_column"): t.String(),
-            t.Key("date_format"): t.String(),
-            t.Key("autopilot_data_selection_method"): t.String(),
-            t.Key("validation_duration", optional=True): t.String(),
+            t.Key("project_id"): String(),
+            t.Key("datetime_partition_column"): String(),
+            t.Key("date_format"): String(),
+            t.Key("autopilot_data_selection_method"): String(),
+            t.Key("validation_duration", optional=True): String(),
             t.Key("available_training_start_date"): parse_time,
-            t.Key("available_training_duration"): t.String(),
-            t.Key("available_training_row_count", optional=True): t.Int(),
+            t.Key("available_training_duration"): String(),
+            t.Key("available_training_row_count", optional=True): Int(),
             t.Key("available_training_end_date"): parse_time,
             t.Key("primary_training_start_date", optional=True): parse_time,
-            t.Key("primary_training_duration"): t.String(),
-            t.Key("primary_training_row_count", optional=True): t.Int(),
+            t.Key("primary_training_duration"): String(),
+            t.Key("primary_training_row_count", optional=True): Int(),
             t.Key("primary_training_end_date", optional=True): parse_time,
             t.Key("gap_start_date", optional=True): parse_time,
-            t.Key("gap_duration"): t.String(),
-            t.Key("gap_row_count", optional=True): t.Int(),
+            t.Key("gap_duration"): String(),
+            t.Key("gap_row_count", optional=True): Int(),
             t.Key("gap_end_date", optional=True): parse_time,
             t.Key("disable_holdout", optional=True): t.Bool,
             t.Key("holdout_start_date", optional=True): parse_time,
-            t.Key("holdout_duration"): t.String(),
-            t.Key("holdout_row_count", optional=True): t.Int(),
+            t.Key("holdout_duration"): String(),
+            t.Key("holdout_row_count", optional=True): Int(),
             t.Key("holdout_end_date", optional=True): parse_time,
-            t.Key("number_of_backtests"): t.Int(),
+            t.Key("number_of_backtests"): Int(),
             t.Key("backtests"): t.List(_backtest_converter),
-            t.Key("total_row_count", optional=True): t.Int(),
+            t.Key("total_row_count", optional=True): Int(),
             t.Key("use_time_series", optional=True, default=False): t.Bool(),
             t.Key("default_to_known_in_advance", optional=True, default=False): t.Bool(),
             t.Key("default_to_do_not_derive", optional=True, default=False): t.Bool(),
-            t.Key("feature_derivation_window_start", optional=True): t.Int(),
-            t.Key("feature_derivation_window_end", optional=True): t.Int(),
+            t.Key("feature_derivation_window_start", optional=True): Int(),
+            t.Key("feature_derivation_window_end", optional=True): Int(),
             t.Key("feature_settings", optional=True): t.List(_feature_settings_converter),
-            t.Key("forecast_window_start", optional=True): t.Int(),
-            t.Key("forecast_window_end", optional=True): t.Int(),
+            t.Key("forecast_window_start", optional=True): Int(),
+            t.Key("forecast_window_end", optional=True): Int(),
             t.Key("windows_basis_unit", optional=True): t.Enum(
                 TIME_UNITS.MILLISECOND,
                 TIME_UNITS.SECOND,
@@ -1372,17 +1373,17 @@ class DatetimePartitioning(object):
                 DIFFERENCING_METHOD.SEASONAL,
             ),
             t.Key("periodicities", optional=True): t.List(_periodicity_converter),
-            t.Key("multiseries_id_columns", optional=True): t.List(t.String()),
-            t.Key("number_of_known_in_advance_features"): t.Int(),
-            t.Key("number_of_do_not_derive_features"): t.Int(),
+            t.Key("multiseries_id_columns", optional=True): t.List(String()),
+            t.Key("number_of_known_in_advance_features"): Int(),
+            t.Key("number_of_do_not_derive_features"): Int(),
             t.Key("use_cross_series_features", optional=True): t.Bool,
             t.Key("aggregation_type", optional=True): t.Enum(
                 SERIES_AGGREGATION_TYPE.AVERAGE, SERIES_AGGREGATION_TYPE.TOTAL
             ),
-            t.Key("cross_series_group_by_columns", optional=True): t.List(t.String()),
-            t.Key("calendar_id", optional=True): t.String(),
-            t.Key("calendar_name", optional=True): t.String(),
-            t.Key("model_splits", optional=True): t.Int(),
+            t.Key("cross_series_group_by_columns", optional=True): t.List(String()),
+            t.Key("calendar_id", optional=True): String(),
+            t.Key("calendar_name", optional=True): String(),
+            t.Key("model_splits", optional=True): Int(),
             t.Key("allow_partial_history_time_series_predictions", optional=True): t.Bool,
         }
     ).ignore_extra("*")
