@@ -2,6 +2,7 @@ from operator import itemgetter
 
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.models.api_object import APIObject
 
 from ..enums import AnomalyAssessmentStatus, SOURCE_TYPE
@@ -13,12 +14,12 @@ DEFAULT_BATCH_SIZE = 1000
 
 RecordMetadataTrafaret = t.Dict(
     {
-        t.Key("record_id"): t.String,
-        t.Key("project_id"): t.String,
-        t.Key("model_id"): t.String,
-        t.Key("backtest"): t.String() | t.Int,
+        t.Key("record_id"): String,
+        t.Key("project_id"): String,
+        t.Key("model_id"): String,
+        t.Key("backtest"): String() | Int,
         t.Key("source"): t.Enum(*SOURCE_TYPE.ALL),
-        t.Key("series_id"): t.String() | t.Null,
+        t.Key("series_id"): String() | t.Null,
     }
 )
 
@@ -138,13 +139,13 @@ class AnomalyAssessmentRecord(BaseAPIObject):
         t.Dict(
             {
                 t.Key("status"): t.Enum(*AnomalyAssessmentStatus.ALL),
-                t.Key("status_details"): t.String,
-                t.Key("start_date"): t.String() | t.Null,
-                t.Key("end_date"): t.String() | t.Null,
+                t.Key("status_details"): String,
+                t.Key("start_date"): String() | t.Null,
+                t.Key("end_date"): String() | t.Null,
                 t.Key("prediction_threshold"): t.Float | t.Null,
-                t.Key("preview_location"): t.String() | t.Null,
-                t.Key("delete_location"): t.String(),
-                t.Key("latest_explanations_location"): t.String() | t.Null,
+                t.Key("preview_location"): String() | t.Null,
+                t.Key("delete_location"): String(),
+                t.Key("latest_explanations_location"): String() | t.Null,
             }
         )
         .merge(RecordMetadataTrafaret)
@@ -415,17 +416,17 @@ class AnomalyAssessmentPredictionsPreview(BaseAPIObject):
         {
             t.Key("avg_predicted"): t.Float() | t.Null,
             t.Key("max_predicted"): t.Float() | t.Null,
-            t.Key("start_date"): t.String,
-            t.Key("end_date"): t.String,
-            t.Key("frequency"): t.Int,
+            t.Key("start_date"): String,
+            t.Key("end_date"): String,
+            t.Key("frequency"): Int,
         }
     )
 
     _converter = (
         t.Dict(
             {
-                t.Key("start_date"): t.String,
-                t.Key("end_date"): t.String,
+                t.Key("start_date"): String,
+                t.Key("end_date"): String,
                 t.Key("preview_bins"): t.List(PreviewBinTrafaret),
             }
         )
@@ -554,13 +555,13 @@ class AnomalyAssessmentExplanations(BaseAPIObject):
     _path = "projects/{project_id}/anomalyAssessmentRecords/{record_id}/explanations/"
 
     ShapContributionTrafaret = t.Dict(
-        {t.Key("feature_value"): t.String, t.Key("strength"): t.Float, t.Key("feature"): t.String}
+        {t.Key("feature_value"): String, t.Key("strength"): t.Float, t.Key("feature"): String}
     )
 
     RowTrafaret = t.Dict(
         {
             t.Key("shap_explanation"): t.List(ShapContributionTrafaret) | t.Null,
-            t.Key("timestamp"): t.String,
+            t.Key("timestamp"): String,
             t.Key("prediction"): t.Float,
         }
     )
@@ -568,11 +569,11 @@ class AnomalyAssessmentExplanations(BaseAPIObject):
     _converter = (
         t.Dict(
             {
-                t.Key("count"): t.Int,
+                t.Key("count"): Int,
                 t.Key("shap_base_value"): t.Float,
                 t.Key("data"): t.List(RowTrafaret),
-                t.Key("start_date"): t.String() | t.Null,
-                t.Key("end_date"): t.String() | t.Null,
+                t.Key("start_date"): String() | t.Null,
+                t.Key("end_date"): String() | t.Null,
             }
         )
         .merge(RecordMetadataTrafaret)
