@@ -1,10 +1,15 @@
+import csv
 import datetime
+import io
 import threading
 import time
 
+import pandas as pd
+import six
 import trafaret as t
 
 from datarobot import errors
+from datarobot._compat import Int, String
 from datarobot.models.credential import Credential
 from datarobot.models.dataset import Dataset
 from datarobot.models.job import AbstractSpecificJob
@@ -16,10 +21,12 @@ from datarobot.utils import (
     to_api,
 )
 
-from ..enums import AVAILABLE_STATEMENT_TYPES, JOB_TYPE, QUEUE_STATUS
-from ..utils import parse_time
+from ..enums import AVAILABLE_STATEMENT_TYPES, DEFAULT_TIMEOUT, JOB_TYPE, QUEUE_STATUS
+from ..utils import logger, parse_time
 from .api_object import APIObject
 
+LOG = logger.get_logger(__name__)
+
 
 class BatchPredictionJob(AbstractSpecificJob):
     """
@@ -34,13 +41,13 @@ class BatchPredictionJob(AbstractSpecificJob):
 
     _job_spec = t.Dict(
         {
-            t.Key("num_concurrent"): t.Int(),
+            t.Key("num_concurrent"): Int(),
             t.Key("threshold_high", optional=True): t.Float(),
             t.Key("threshold_low", optional=True): t.Float(),
-            t.Key("deployment_id"): t.String(),
-            t.Key("passthrough_columns", optional=True): t.List(t.String(allow_blank=True)),
-            t.Key("passthrough_columns_set", optional=True): t.String(),
-            t.Key("max_explanations", optional=True): t.Int(),
+            t.Key("deployment_id"): String(),
+            t.Key("passthrough_columns", optional=True): t.List(String(allow_blank=True)),
+            t.Key("passthrough_columns_set", optional=True): String(),
+            t.Key("max_explanations", optional=True): Int(),
             t.Key("prediction_warning_enabled", optional=True): t.Bool(),
             t.Key("intake_settings", optional=True): t.Dict().allow_extra("*"),
             t.Key("output_settings", optional=True): t.Dict().allow_extra("*"),
@@ -48,21 +55,21 @@ class BatchPredictionJob(AbstractSpecificJob):
         }
     ).allow_extra("*")
     _links = t.Dict(
-        {t.Key("download", optional=True): t.String(allow_blank=True), t.Key("self"): t.String()}
+        {t.Key("download", optional=True): String(allow_blank=True), t.Key("self"): String()}
     ).allow_extra("*")
     _converter_extra = t.Dict(
         {
             t.Key("percentage_completed"): t.Float(),
-            t.Key("elapsed_time_sec"): t.Int(),
+            t.Key("elapsed_time_sec"): Int(),
             t.Key("links"): _links,
             t.Key("job_spec"): _job_spec,
-            t.Key("status_details"): t.String(),
+            t.Key("status_details"): String(),
         }
     ).allow_extra("*")
 
     _converter_common = t.Dict(
         {
-            t.Key("id", optional=True): t.String,
+            t.Key("id", optional=True): String,
             t.Key("status", optional=True): t.Enum(
                 QUEUE_STATUS.ABORTED,
                 QUEUE_STATUS.COMPLETED,
@@ -70,46 +77,44 @@ class BatchPredictionJob(AbstractSpecificJob):
                 QUEUE_STATUS.INITIALIZING,
                 "FAILED",
             ),
-            t.Key("project_id", optional=True): t.String,
+            t.Key("project_id", optional=True): String,
             t.Key("is_blocked", optional=True): t.Bool,
         }
     )
 
-    _s3_settings = t.Dict(
-        {t.Key("url"): t.String(), t.Key("credential_id", optional=True): t.String()}
-    )
+    _s3_settings = t.Dict({t.Key("url"): String(), t.Key("credential_id", optional=True): String()})
 
     _dataset_intake_settings = t.Dict(
-        {t.Key("dataset"): t.Type(Dataset), t.Key("dataset_version_id", optional=True): t.String()}
+        {t.Key("dataset"): t.Type(Dataset), t.Key("dataset_version_id", optional=True): String()}
     )
 
     _jdbc_intake_settings = t.Dict(
         {
-            t.Key("data_store_id"): t.String(),
-            t.Key("query", optional=True): t.String(),
-            t.Key("table", optional=True): t.String(),
-            t.Key("schema", optional=True): t.String(),
-            t.Key("catalog", optional=True): t.String(),
-            t.Key("fetch_size", optional=True): t.Int(),
-            t.Key("credential_id", optional=True): t.String(),
+            t.Key("data_store_id"): String(),
+            t.Key("query", optional=True): String(),
+            t.Key("table", optional=True): String(),
+            t.Key("schema", optional=True): String(),
+            t.Key("catalog", optional=True): String(),
+            t.Key("fetch_size", optional=True): Int(),
+            t.Key("credential_id", optional=True): String(),
         }
     )
 
     _jdbc_output_settings = t.Dict(
         {
-            t.Key("data_store_id"): t.String(),
-            t.Key("table"): t.String(),
-            t.Key("schema", optional=True): t.String(),
-            t.Key("catalog", optional=True): t.String(),
+            t.Key("data_store_id"): String(),
+            t.Key("table"): String(),
+            t.Key("schema", optional=True): String(),
+            t.Key("catalog", optional=True): String(),
             t.Key("statement_type"): t.Enum(
                 AVAILABLE_STATEMENT_TYPES.INSERT,
                 AVAILABLE_STATEMENT_TYPES.UPDATE,
                 AVAILABLE_STATEMENT_TYPES.INSERT_UPDATE,
                 AVAILABLE_STATEMENT_TYPES.CREATE_TABLE,
             ),
-            t.Key("update_columns", optional=True): t.List(t.String),
-            t.Key("where_columns", optional=True): t.List(t.String),
-            t.Key("credential_id", optional=True): t.String(),
+            t.Key("update_columns", optional=True): t.List(String),
+            t.Key("where_columns", optional=True): t.List(String),
+            t.Key("credential_id", optional=True): String(),
         }
     )
 
@@ -130,22 +135,22 @@ class BatchPredictionJob(AbstractSpecificJob):
 
     _csv_settings = t.Dict(
         {
-            t.Key("delimiter", optional=True): t.Atom("tab") | t.String(min_length=1, max_length=1),
-            t.Key("quotechar", optional=True): t.String(),
-            t.Key("encoding", optional=True): t.String(),
+            t.Key("delimiter", optional=True): t.Atom("tab") | String(min_length=1, max_length=1),
+            t.Key("quotechar", optional=True): String(),
+            t.Key("encoding", optional=True): String(),
         }
     )
 
     _prediction_instance = t.Dict(
         {
-            t.Key("hostName"): t.String(),
+            t.Key("hostName"): String(),
             t.Key("sslEnabled", optional=True): t.Bool(),
-            t.Key("datarobotKey", optional=True): t.String(),
-            t.Key("apiKey", optional=True): t.String(),
+            t.Key("datarobotKey", optional=True): String(),
+            t.Key("apiKey", optional=True): String(),
         }
     )
 
-    _column_names_remapping = t.Mapping(t.String, t.String | t.Null())
+    _column_names_remapping = t.Mapping(String, String | t.Null())
 
     @classmethod
     def _job_type(cls):
@@ -188,6 +193,7 @@ class BatchPredictionJob(AbstractSpecificJob):
         include_probabilities_classes=None,
         download_timeout=120,
         download_read_timeout=660,
+        upload_read_timeout=DEFAULT_TIMEOUT.UPLOAD,
     ):
         """
         Create new batch prediction job, upload the scoring dataset and
@@ -412,6 +418,12 @@ class BatchPredictionJob(AbstractSpecificJob):
             If using localFile output, wait this many seconds for the server to respond
             between chunks.
 
+        upload_read_timeout: int (optional, default 600)
+            .. versionadded:: 2.28
+
+            If using localFile intake, wait this many seconds for the server to respond
+            after whole dataset upload.
+
         Returns
         -------
         BatchPredictionJob
@@ -648,6 +660,7 @@ class BatchPredictionJob(AbstractSpecificJob):
                         url=job_response["links"]["csvUpload"],
                         data=fileobj,
                         headers={"content-type": "text/csv"},
+                        timeout=(_upload_client.connect_timeout, upload_read_timeout),
                     )
                 finally:
                     if hasattr(fileobj, "close"):
@@ -905,6 +918,136 @@ class BatchPredictionJob(AbstractSpecificJob):
         job_id = get_id_from_response(response)
         return BatchPredictionJob.get(job_id)
 
+    @classmethod
+    def score_pandas(cls, deployment, df, read_timeout=660, **kwargs):
+        """
+        Run a batch prediction job, with a scoring dataset from a
+        pandas dataframe. The output from the prediction will be joined
+        to the passed DataFrame and returned.
+
+        Use `columnNamesRemapping` to drop or rename columns in the
+        output
+
+        This method blocks until the job has completed or raises an
+        exception on errors.
+
+        Refer to the `create` method for details on the other `kwargs`
+        parameters.
+
+        Attributes
+        ----------
+        deployment : Deployment or string ID
+            Deployment which will be used for scoring.
+
+        df : pandas.DataFrame
+            The dataframe to score
+
+        Returns
+        -------
+        BatchPredictionJob
+            Instance of BatchPredictonJob
+        pandas.DataFrame
+            The original dataframe merged with the predictions
+        """
+
+        chunk_size = 10000
+        index_label = "__DR_index__"
+
+        class FileFromChunks(io.RawIOBase):
+            """
+            File-like object built from an iterator of chunks.
+            """
+
+            def __init__(self, iterator):
+                self._iterator = iterator
+                self._buffer = None
+                self._read_bytes = 0
+
+            def readable(self):
+                return True
+
+            def readinto(self, b):
+                read_size = len(b)
+                if self._buffer:
+                    if len(self._buffer) < read_size:
+                        chunk = self._buffer.tobytes()
+                        while len(chunk) < read_size:
+                            try:
+                                chunk += next(self._iterator)
+                            except StopIteration:
+                                break
+                        chunk = memoryview(chunk)
+                    else:
+                        chunk = self._buffer
+                else:
+                    try:
+                        chunk = next(self._iterator)
+                    except StopIteration:
+                        return 0
+
+                    while len(chunk) < read_size:
+                        try:
+                            chunk += next(self._iterator)
+                        except StopIteration:
+                            break
+                    chunk = memoryview(chunk)
+
+                output, self._buffer = chunk[:read_size], chunk[read_size:]
+                b[: len(output)] = output
+
+                self._read_bytes += len(output)
+                return len(output)
+
+            def tell(self):
+                return self._read_bytes
+
+            def seek(self, n):
+                if n != self.tell():
+                    raise RuntimeError("Cannot seek")
+
+        def csv_stream():
+            LOG.info("Streaming DataFrame as CSV data to DataRobot")
+            for chunk_no, chunked_df in enumerate(
+                df[i : i + chunk_size] for i in range(0, df.shape[0], chunk_size)
+            ):
+                yield six.ensure_binary(
+                    chunked_df.to_csv(
+                        index_label=index_label, header=(chunk_no == 0), quoting=csv.QUOTE_ALL
+                    )
+                )
+
+        kwargs["intake_settings"] = {"type": "localFile", "file": FileFromChunks(csv_stream())}
+        kwargs["output_settings"] = {"type": "localFile"}
+
+        if kwargs.get("passthrough_columns_set") != "all":
+            # If we're not passing everything through, ensure we're passing the index
+            # used to join the results
+            kwargs.setdefault("passthrough_columns", []).append(index_label)
+
+        job = cls.score(deployment, **kwargs)
+
+        status = job.get_status()
+        LOG.info("Created Batch Prediction job ID %s", job.id)
+        LOG.info("Waiting for DataRobot to start processing")
+
+        status = job._wait_for_download(timeout=read_timeout)
+        LOG.info("Job has started processing at DataRobot. Streaming results.")
+
+        status = job.get_status()
+        resp = job._client.get(status["links"]["download"], stream=True, timeout=read_timeout)
+        if resp.status_code != 200:
+            raise RuntimeError(
+                (
+                    "Got invalid response when downloading job data. "
+                    "Status code: %s, Reponse: %s, Job ID: %s"
+                )
+                % (resp.status_code, resp.content, job.id)
+            )
+
+        scored_df = pd.read_csv(resp.raw, index_col=index_label)
+
+        return job, df.merge(scored_df, left_index=True, right_index=True, how="inner")
+
     @classmethod
     def get(cls, batch_prediction_job_id):
         """Get batch prediction job
@@ -951,6 +1094,22 @@ class BatchPredictionJob(AbstractSpecificJob):
 
             Seconds to wait for the server to respond between chunks.
         """
+        status = self._wait_for_download(timeout=timeout)
+        download_iter = self._client.get(
+            status["links"]["download"], stream=True, timeout=read_timeout,
+        ).iter_content(chunk_size=8192)
+
+        for chunk in download_iter:
+            if chunk:
+                fileobj.write(chunk)
+
+        # Check if job was aborted during download (and the download is incomplete)
+        status = self.get_status()
+        if status["status"] in ("ABORTED", "FAILED"):
+            raise RuntimeError("Job {0} was aborted: {1}".format(self.id, status["status_details"]))
+
+    def _wait_for_download(self, timeout=120):
+        """ Waits for download to become available """
         start = time.time()
         status = None
         while True:
@@ -979,18 +1138,7 @@ class BatchPredictionJob(AbstractSpecificJob):
                 ).format(self.id)
             )
 
-        download_iter = self._client.get(
-            status["links"]["download"], stream=True, timeout=read_timeout,
-        ).iter_content(chunk_size=8192)
-
-        for chunk in download_iter:
-            if chunk:
-                fileobj.write(chunk)
-
-        # Check if job was aborted during download (and the download is incomplete)
-        status = self.get_status()
-        if status["status"] in ("ABORTED", "FAILED"):
-            raise RuntimeError("Job {0} was aborted: {1}".format(self.id, status["status_details"]))
+        return status
 
     def delete(self, ignore_404_errors=False):
         """
@@ -1072,37 +1220,37 @@ class BatchPredictionJobDefinition(APIObject):
 
     _user = t.Dict(
         {
-            t.Key("username"): t.String(),
-            t.Key("full_name", optional=True): t.String(),
-            t.Key("user_id"): t.String(),
+            t.Key("username"): String(),
+            t.Key("full_name", optional=True): String(),
+            t.Key("user_id"): String(),
         }
     ).allow_extra("*")
 
     _schedule = t.Dict(
         {
-            t.Key("day_of_week"): t.List(t.Or(t.String, t.Int)),
-            t.Key("month"): t.List(t.Or(t.String, t.Int)),
-            t.Key("hour"): t.List(t.Or(t.String, t.Int)),
-            t.Key("minute"): t.List(t.Or(t.String, t.Int)),
-            t.Key("day_of_month"): t.List(t.Or(t.String, t.Int)),
+            t.Key("day_of_week"): t.List(t.Or(String, Int)),
+            t.Key("month"): t.List(t.Or(String, Int)),
+            t.Key("hour"): t.List(t.Or(String, Int)),
+            t.Key("minute"): t.List(t.Or(String, Int)),
+            t.Key("day_of_month"): t.List(t.Or(String, Int)),
         }
     ).allow_extra("*")
 
     _converter = t.Dict(
         {
-            t.Key("id"): t.String,
-            t.Key("name"): t.String,
+            t.Key("id"): String,
+            t.Key("name"): String,
             t.Key("enabled"): t.Bool(),
             t.Key("schedule", optional=True): _schedule,
             t.Key("batch_prediction_job"): BatchPredictionJob._job_spec,
-            t.Key("created"): t.String(),
-            t.Key("updated"): t.String(),
+            t.Key("created"): String(),
+            t.Key("updated"): String(),
             t.Key("created_by"): _user,
             t.Key("updated_by"): _user,
-            t.Key("last_failed_run_time", optional=True): t.String(),
-            t.Key("last_successful_run_time", optional=True): t.String(),
-            t.Key("last_successful_run_time", optional=True): t.String(),
-            t.Key("last_scheduled_run_time", optional=True): t.String(),
+            t.Key("last_failed_run_time", optional=True): String(),
+            t.Key("last_successful_run_time", optional=True): String(),
+            t.Key("last_successful_run_time", optional=True): String(),
+            t.Key("last_scheduled_run_time", optional=True): String(),
         }
     ).allow_extra("*")
 
