@@ -4,6 +4,7 @@ import os
 import six
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.client import get_client, staticproperty
 from datarobot.models.api_object import APIObject
 from datarobot.models.sharing import SharingAccess
@@ -58,16 +59,16 @@ class CalendarFile(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("calendar_end_date"): t.String,
-            t.Key("calendar_start_date"): t.String,
-            t.Key("created"): t.String,
-            t.Key("id"): t.String,
-            t.Key("name"): t.String,
-            t.Key("num_event_types"): t.Int,
-            t.Key("num_events"): t.Int,
-            t.Key("project_ids"): t.List(t.String),
-            t.Key("role"): t.String,
-            t.Key("multiseries_id_columns", optional=True): t.Or(t.List(t.String), t.Null),
+            t.Key("calendar_end_date"): String,
+            t.Key("calendar_start_date"): String,
+            t.Key("created"): String,
+            t.Key("id"): String,
+            t.Key("name"): String,
+            t.Key("num_event_types"): Int,
+            t.Key("num_events"): Int,
+            t.Key("project_ids"): t.List(String),
+            t.Key("role"): String,
+            t.Key("multiseries_id_columns", optional=True): t.Or(t.List(String), t.Null),
         }
     ).ignore_extra("*")
 
