@@ -1,5 +1,6 @@
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.enums import CUSTOM_MODEL_TARGET_TYPE, DEFAULT_MAX_WAIT, NETWORK_EGRESS_POLICY
 from datarobot.errors import ClientError
 from datarobot.models.api_object import APIObject
@@ -14,19 +15,19 @@ class _CustomModelBase(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("id"): t.String(),
-            t.Key("name"): t.String(),
-            t.Key("description"): t.String(allow_blank=True),
+            t.Key("id"): String(),
+            t.Key("name"): String(),
+            t.Key("description"): String(allow_blank=True),
             t.Key("supports_binary_classification", optional=True, default=False): t.Bool(),
             t.Key("supports_regression", optional=True, default=False): t.Bool(),
             t.Key("latest_version", optional=True, default=None): t.Or(
                 CustomModelVersion.schema, t.Null()
             ),
-            t.Key("deployments_count"): t.Int(),
-            t.Key("created_by"): t.String(),
-            t.Key("updated") >> "updated_at": t.String(),
-            t.Key("created") >> "created_at": t.String(),
-            t.Key("target_type", optional=True, default=None): t.String(),
+            t.Key("deployments_count", optional=True, default=None): Int(),
+            t.Key("created_by"): String(),
+            t.Key("updated") >> "updated_at": String(),
+            t.Key("created") >> "created_at": String(),
+            t.Key("target_type", optional=True, default=None): String(),
         }
     ).ignore_extra("*")
 
@@ -233,20 +234,20 @@ class CustomInferenceModel(_CustomModelBase):
     _converter = (
         _CustomModelBase._converter
         + {
-            t.Key("language"): t.String(allow_blank=True),
-            t.Key("target_name", optional=True): t.String(),
-            t.Key("training_dataset_id", optional=True): t.String(),
-            t.Key("training_dataset_version_id", optional=True): t.String(),
+            t.Key("language"): String(allow_blank=True),
+            t.Key("target_name", optional=True): String(),
+            t.Key("training_dataset_id", optional=True): String(),
+            t.Key("training_dataset_version_id", optional=True): String(),
             t.Key("training_data_assignment_in_progress"): t.Bool(),
-            t.Key("positive_class_label", optional=True): t.String(),
-            t.Key("negative_class_label", optional=True): t.String(),
-            t.Key("class_labels", optional=True): t.List(t.String()),
+            t.Key("positive_class_label", optional=True): String(),
+            t.Key("negative_class_label", optional=True): String(),
+            t.Key("class_labels", optional=True): t.List(String()),
             t.Key("prediction_threshold", optional=True): t.Float(),
-            t.Key("training_data_file_name", optional=True): t.String(),
-            t.Key("training_data_partition_column", optional=True): t.String(),
+            t.Key("training_data_file_name", optional=True): String(),
+            t.Key("training_data_partition_column", optional=True): String(),
             t.Key("network_egress_policy", optional=True): t.Enum(*NETWORK_EGRESS_POLICY.ALL),
-            t.Key("maximum_memory", optional=True): t.Int(),
-            t.Key("replicas", optional=True): t.Int(),
+            t.Key("maximum_memory", optional=True): Int(),
+            t.Key("replicas", optional=True): Int(),
         }
     ).allow_extra("*")
 
