@@ -7,15 +7,53 @@ from requests_toolbelt import MultipartEncoder
 from six import string_types
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.enums import DEFAULT_MAX_WAIT, NETWORK_EGRESS_POLICY
 from datarobot.models.api_object import APIObject
 from datarobot.models.job import filter_feature_impact_result
 from datarobot.models.validators import feature_impact_trafaret
-from datarobot.utils import encode_utf8_if_py2
+from datarobot.utils import camelize, deprecation_warning, encode_utf8_if_py2
 from datarobot.utils.pagination import unpaginate
 from datarobot.utils.waiters import wait_for_async_resolution, wait_for_custom_resolution
 
 
+class RequiredMetadataValue(APIObject):
+    """Definition of a metadata key that custom models using this environment must define
+
+    .. versionadded:: v2.26
+
+    Attributes
+    ----------
+    field_name: str
+        The required field names.  Required field names are defined by the
+        environment's required_metadata_keys. This value will be added as an
+        environment vairable when running custom models.
+    value: str
+        the value for the required field.
+    """
+
+    _converter = t.Dict({t.Key("field_name"): String(), t.Key("value"): String()})
+
+    schema = _converter
+
+    def __init__(self, **kwargs):
+        self._set_values(**kwargs)
+
+    def __repr__(self):
+        return encode_utf8_if_py2(
+            u"{}(field_name={!r}, value={!r})".format(
+                self.__class__.__name__, self.field_name, self.value,
+            )
+        )
+
+    def _set_values(self, field_name, value):
+        self.field_name = field_name
+        self.value = value
+
+    def to_dict(self):
+        return self._converter.check({"field_name": self.field_name, "value": self.value})
+
+
 class CustomModelFileItem(APIObject):
     """A file item attached to a DataRobot custom model version.
 
@@ -37,11 +75,11 @@ class CustomModelFileItem(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("id"): t.String(),
-            t.Key("file_name"): t.String(),
-            t.Key("file_path"): t.String(),
-            t.Key("file_source"): t.String(),
-            t.Key("created", optional=True) >> "created_at": t.String(),
+            t.Key("id"): String(),
+            t.Key("file_name"): String(),
+            t.Key("file_path"): String(),
+            t.Key("file_source"): String(),
+            t.Key("created", optional=True) >> "created_at": String(),
         }
     ).ignore_extra("*")
 
@@ -81,11 +119,11 @@ class CustomModelVersionDependencyBuild(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("custom_model_id"): t.String(),
-            t.Key("custom_model_version_id"): t.String(),
-            t.Key("build_status"): t.String(),
-            t.Key("build_start") >> "started_at": t.String(),
-            t.Key("build_end", optional=True) >> "completed_at": t.String(allow_blank=True),
+            t.Key("custom_model_id"): String(),
+            t.Key("custom_model_version_id"): String(),
+            t.Key("build_status"): String(),
+            t.Key("build_start") >> "started_at": String(),
+            t.Key("build_end", optional=True) >> "completed_at": String(allow_blank=True),
         }
     ).ignore_extra("*")
 
@@ -252,7 +290,7 @@ class CustomDependencyConstraint(APIObject):
     """
 
     _converter = t.Dict(
-        {t.Key("constraint_type"): t.String(), t.Key("version"): t.String()}
+        {t.Key("constraint_type"): String(), t.Key("version"): String()}
     ).ignore_extra("*")
 
     schema = _converter
@@ -291,10 +329,10 @@ class CustomDependency(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("package_name"): t.String(),
+            t.Key("package_name"): String(),
             t.Key("constraints"): t.List(CustomDependencyConstraint.schema),
-            t.Key("line"): t.String(),
-            t.Key("line_number"): t.Int(gt=0),
+            t.Key("line"): String(),
+            t.Key("line_number"): Int(gt=0),
         }
     ).ignore_extra("*")
 
@@ -357,35 +395,41 @@ class CustomModelVersion(APIObject):
         If exceeded, the custom-model will be killed by k8s
     replicas: int, optional
         A fixed number of replicas that will be deployed in the cluster
-    required_metadata: Dict[str, str]
+    required_metadata_values: List[RequiredMetadataValue]
         Additional parameters required by the execution environment. The required keys are
-        defined by the fieldNames in the base envionment's requiredMetadataKeys. Once set,
-        they cannot be changed. If you to change them, make a new version.
+        defined by the fieldNames in the base environment's requiredMetadataKeys.
+    required_metadata: Dict[str, str]
+        Deprecated in v2.26. Use require_metadata_values instead.
+
+        Additional parameters required by the execution environment. The required keys are
+        defined by the fieldNames in the base environment's requiredMetadataKeys. Once set,
+        they cannot be changed. If you want to change them, make a new version.
     """
 
     _path = "customModels/{}/versions/"
 
     _converter = t.Dict(
         {
-            t.Key("id"): t.String(),
-            t.Key("custom_model_id"): t.String(),
-            t.Key("version_minor"): t.Int(),
-            t.Key("version_major"): t.Int(),
+            t.Key("id"): String(),
+            t.Key("custom_model_id"): String(),
+            t.Key("version_minor"): Int(),
+            t.Key("version_major"): Int(),
             t.Key("is_frozen"): t.Bool(),
             t.Key("items"): t.List(CustomModelFileItem.schema),
             # base_environment_id will be required once dependency management is enabled by default
             # in 6.2, but for backwards compatibility, this should be optional
-            t.Key("base_environment_id", optional=True): t.String(),
-            t.Key("base_environment_version_id", optional=True): t.String(),
-            t.Key("label", optional=True): t.String(max_length=50, allow_blank=True) | t.Null(),
-            t.Key("description", optional=True): t.String(max_length=10000, allow_blank=True)
+            t.Key("base_environment_id", optional=True): String(),
+            t.Key("base_environment_version_id", optional=True): String(),
+            t.Key("label", optional=True): String(max_length=50, allow_blank=True) | t.Null(),
+            t.Key("description", optional=True): String(max_length=10000, allow_blank=True)
             | t.Null(),
-            t.Key("created", optional=True) >> "created_at": t.String(),
+            t.Key("created", optional=True) >> "created_at": String(),
             t.Key("dependencies", optional=True): t.List(CustomDependency.schema),
             t.Key("network_egress_policy", optional=True): t.Enum(*NETWORK_EGRESS_POLICY.ALL),
-            t.Key("maximum_memory", optional=True): t.Int(),
-            t.Key("replicas", optional=True): t.Int(),
-            t.Key("required_metadata", optional=True): t.Mapping(t.String(), t.String()),
+            t.Key("maximum_memory", optional=True): Int(),
+            t.Key("replicas", optional=True): Int(),
+            t.Key("required_metadata_values", optional=True): t.List(RequiredMetadataValue.schema),
+            t.Key("required_metadata", optional=True): t.Mapping(String(), String()),
         }
     ).ignore_extra("*")
 
@@ -417,6 +461,7 @@ class CustomModelVersion(APIObject):
         maximum_memory=None,
         replicas=None,
         required_metadata=None,
+        required_metadata_values=None,
     ):
         self.id = id
         self.custom_model_id = custom_model_id
@@ -434,6 +479,11 @@ class CustomModelVersion(APIObject):
         self.maximum_memory = maximum_memory
         self.replicas = replicas
         self.required_metadata = required_metadata
+        self.required_metadata_values = (
+            [RequiredMetadataValue.from_server_data(val) for val in required_metadata_values]
+            if required_metadata_values
+            else None
+        )
 
     @classmethod
     def from_server_data(cls, data, keep_attrs=None):
@@ -455,6 +505,7 @@ class CustomModelVersion(APIObject):
         maximum_memory=None,
         replicas=None,
         required_metadata=None,
+        required_metadata_values=None,
     ):
         """Create a custom model version without files from previous versions.
 
@@ -493,9 +544,14 @@ class CustomModelVersion(APIObject):
         replicas: int, optional
             A fixed number of replicas that will be deployed in the cluster
         required_metadata: Dict[str, str]
+            Deprecated in v2.26. Use require_metadata_values instead.
+
             Additional parameters required by the execution environment. The required keys are
-            defined by the fieldNames in the base envionment's requiredMetadataKeys. Once set,
-            they cannot be changed. If you to change them, make a new version.
+            defined by the fieldNames in the base environment's requiredMetadataKeys. Once set,
+            they cannot be changed. If you want to change them, make a new version.
+        required_metadata_values: List[RequiredMetadataValue]
+            Additional parameters required by the execution environment. The required keys are
+            defined by the fieldNames in the base environment's requiredMetadataKeys.
 
         Returns
         -------
@@ -522,6 +578,7 @@ class CustomModelVersion(APIObject):
             maximum_memory=maximum_memory,
             replicas=replicas,
             required_metadata=required_metadata,
+            required_metadata_values=required_metadata_values,
         )
 
     @classmethod
@@ -537,6 +594,7 @@ class CustomModelVersion(APIObject):
         maximum_memory=None,
         replicas=None,
         required_metadata=None,
+        required_metadata_values=None,
     ):
         """Create a custom model version containing files from a previous version.
 
@@ -578,9 +636,14 @@ class CustomModelVersion(APIObject):
         replicas: int, optional
             A fixed number of replicas that will be deployed in the cluster
         required_metadata: Dict[str, str]
+            Deprecated in v2.26. Use require_metadata_values instead.
+
             Additional parameters required by the execution environment. The required keys are
-            defined by the fieldNames in the base envionment's requiredMetadataKeys. Once set,
-            they cannot be changed. If you to change them, make a new version.
+            defined by the fieldNames in the base environment's requiredMetadataKeys. Once set,
+            they cannot be changed. If you want to change them, make a new version.
+        required_metadata_values: List[RequiredMetadataValue]
+            Additional parameters required by the execution environment. The required keys are
+            defined by the fieldNames in the base environment's requiredMetadataKeys.
 
         Returns
         -------
@@ -612,6 +675,7 @@ class CustomModelVersion(APIObject):
             maximum_memory,
             replicas,
             required_metadata=required_metadata,
+            required_metadata_values=required_metadata_values,
         )
 
     @classmethod
@@ -628,6 +692,7 @@ class CustomModelVersion(APIObject):
         maximum_memory=None,
         replicas=None,
         required_metadata=None,
+        required_metadata_values=None,
     ):
         url = cls._path.format(custom_model_id)
 
@@ -665,9 +730,33 @@ class CustomModelVersion(APIObject):
             if replicas:
                 upload_data.append(("replicas", str(replicas)))
 
-            if required_metadata:
+            if required_metadata is not None:
+                deprecation_warning(
+                    "required_metadata",
+                    deprecated_since_version="2.26",
+                    will_remove_version="2.27",
+                    message="Use required_metadata_values instead.",
+                )
+                if required_metadata_values is not None:
+                    raise ValueError(
+                        "Cannot specify both required_metadata and required_metadata_values. "
+                        "Please use required_metadata_values."
+                    )
                 upload_data.append(("requiredMetadata", json.dumps(required_metadata)))
 
+            if required_metadata_values is not None:
+                upload_data.append(
+                    (
+                        "requiredMetadataValues",
+                        json.dumps(
+                            [
+                                {camelize(k): v for k, v in val.to_dict().items()}
+                                for val in required_metadata_values
+                            ]
+                        ),
+                    )
+                )
+
             encoder = MultipartEncoder(fields=upload_data)
             headers = {"Content-Type": encoder.content_type}
             response = cls._client.request(method, url, data=encoder, headers=headers)
@@ -753,7 +842,7 @@ class CustomModelVersion(APIObject):
         with open(file_path, "wb") as f:
             f.write(response.content)
 
-    def update(self, description=None, required_metadata=None):
+    def update(self, description=None, required_metadata=None, required_metadata_values=None):
         """Update custom model version properties.
 
         .. versionadded:: v2.21
@@ -763,9 +852,14 @@ class CustomModelVersion(APIObject):
         description: str
             new custom model version description
         required_metadata: Dict[str, str]
+            Deprecated in v2.26. Use require_metadata_values instead.
+
             Additional parameters required by the execution environment. The required keys are
-            defined by the fieldNames in the base envionment's requiredMetadataKeys. Once set,
-            they cannot be changed. If you to change them, make a new version.
+            defined by the fieldNames in the base environment's requiredMetadataKeys. Once set,
+            they cannot be changed. If you want to change them, make a new version.
+        required_metadata_values: List[RequiredMetadataValue]
+            Additional parameters required by the execution environment. The required keys are
+            defined by the fieldNames in the base environment's requiredMetadataKeys.
 
         Raises
         ------
@@ -777,9 +871,25 @@ class CustomModelVersion(APIObject):
         payload = {}
         if description:
             payload.update({"description": description})
-        if required_metadata:
+        if required_metadata is not None:
+            deprecation_warning(
+                "required_metadata",
+                deprecated_since_version="2.26",
+                will_remove_version="2.27",
+                message="Use required_metadata_values instead.",
+            )
+            if required_metadata_values is not None:
+                raise ValueError(
+                    "Cannot specify both required_metadata and required_metadata_values. "
+                    "Please use required_metadata_values."
+                )
             payload.update({"requiredMetadata": required_metadata})
 
+        if required_metadata_values is not None:
+            payload.update(
+                {"requiredMetadataValues": [val.to_dict() for val in required_metadata_values]}
+            )
+
         url = self._path.format(self.custom_model_id)
         path = "{}{}/".format(url, self.id)
 
