@@ -5,6 +5,7 @@ import dateutil
 from pandas import DataFrame  # noqa F401
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.models.api_object import APIObject
 from datarobot.models.credential import CredentialDataSchema
 from datarobot.models.feature import DatasetFeature
@@ -24,19 +25,19 @@ FeatureTypeCount = namedtuple("FeatureTypeCount", ["count", "feature_type"])
 
 _base_dataset_schema = t.Dict(
     {
-        t.Key("dataset_id"): t.String,
-        t.Key("version_id"): t.String,
-        t.Key("name"): t.String,
-        t.Key("categories"): t.List(t.String),
+        t.Key("dataset_id"): String,
+        t.Key("version_id"): String,
+        t.Key("name"): String,
+        t.Key("categories"): t.List(String),
         t.Key("creation_date") >> "created_at": t.Call(lambda s: dateutil.parser.parse(s)),
-        t.Key("created_by"): t.String,
+        t.Key("created_by"): String,
         t.Key("data_persisted", optional=True): t.Bool,
         t.Key("is_data_engine_eligible"): t.Bool,
         t.Key("is_latest_version"): t.Bool,
         t.Key("is_snapshot"): t.Bool,
-        t.Key("dataset_size", optional=True) >> "size": t.Int,
-        t.Key("row_count", optional=True): t.Int,
-        t.Key("processing_state"): t.String,
+        t.Key("dataset_size", optional=True) >> "size": Int,
+        t.Key("row_count", optional=True): Int,
+        t.Key("processing_state"): String,
     }
 )
 
@@ -150,7 +151,7 @@ class Dataset(APIObject):
         read_timeout: int, optional
             The maximum number of seconds to wait for the server to respond indicating that the
             initial upload is complete
-        max_wait : int, optional
+        max_wait: int, optional
             Time in seconds after which project creation is considered unsuccessful
 
         Returns
@@ -193,7 +194,14 @@ class Dataset(APIObject):
         return dataset
 
     @classmethod
-    def create_from_in_memory_data(cls, data_frame=None, records=None, categories=None):
+    def create_from_in_memory_data(
+        cls,
+        data_frame=None,
+        records=None,
+        categories=None,
+        read_timeout=DEFAULT_TIMEOUT.UPLOAD,
+        max_wait=DEFAULT_MAX_WAIT,
+    ):
         """
         A blocking call that creates a new Dataset from in-memory data. Returns when the dataset has
         been successfully uploaded and processed.
@@ -209,6 +217,11 @@ class Dataset(APIObject):
         categories: list[string], optional
             An array of strings describing the intended use of the dataset. The
             current supported options are "TRAINING" and "PREDICTION".
+        read_timeout: int, optional
+            The maximum number of seconds to wait for the server to respond indicating that the
+            initial upload is complete
+        max_wait: int, optional
+            Time in seconds after which project creation is considered unsuccessful
 
         Returns
         -------
@@ -220,11 +233,18 @@ class Dataset(APIObject):
             buff = dataframe_to_buffer(data_frame)
         else:
             buff = list_of_records_to_buffer(records)
-        return cls.create_from_file(filelike=buff, categories=categories)
+        return cls.create_from_file(
+            filelike=buff, categories=categories, read_timeout=read_timeout, max_wait=max_wait,
+        )
 
     @classmethod
     def create_from_url(
-        cls, url, do_snapshot=None, persist_data_after_ingestion=None, categories=None
+        cls,
+        url,
+        do_snapshot=None,
+        persist_data_after_ingestion=None,
+        categories=None,
+        max_wait=DEFAULT_MAX_WAIT,
     ):
         """
         A blocking call that creates a new Dataset from data stored at a url.
@@ -237,8 +257,8 @@ class Dataset(APIObject):
         do_snapshot: bool, optional
             If unset, uses the server default: True.
             If true, creates a snapshot dataset; if
-            false, creates a remote dataset. Creating snapshots from non-file sources requires an
-            additional permission, `Enable Create Snapshot Data Source`.
+            false, creates a remote dataset. Creating snapshots from non-file sources may be
+            disabled by the permission, `Disable AI Catalog Snapshots`.
         persist_data_after_ingestion: bool, optional
             If unset, uses the server default: True.
             If true, will enforce saving all data
@@ -250,6 +270,8 @@ class Dataset(APIObject):
         categories: list[string], optional
             An array of strings describing the intended use of the dataset. The
             current supported options are "TRAINING" and "PREDICTION".
+        max_wait: int, optional
+            Time in seconds after which project creation is considered unsuccessful
 
         Returns
         -------
@@ -266,7 +288,9 @@ class Dataset(APIObject):
         upload_url = "{}fromURL/".format(cls._path)
         response = cls._client.post(upload_url, data=data)
 
-        new_dataset_location = wait_for_async_resolution(cls._client, response.headers["Location"])
+        new_dataset_location = wait_for_async_resolution(
+            cls._client, response.headers["Location"], max_wait
+        )
         return cls.from_location(new_dataset_location)
 
     @classmethod
@@ -281,6 +305,7 @@ class Dataset(APIObject):
         credential_id=None,
         use_kerberos=None,
         credential_data=None,
+        max_wait=DEFAULT_MAX_WAIT,
     ):
         """
         A blocking call that creates a new Dataset from data stored at a DataSource.
@@ -300,8 +325,8 @@ class Dataset(APIObject):
         do_snapshot: bool, optional
             If unset, uses the server default: True.
             If true, creates a snapshot dataset; if
-            false, creates a remote dataset. Creating snapshots from non-file sources requires an
-            additional permission, `Enable Create Snapshot Data Source`.
+            false, creates a remote dataset. Creating snapshots from non-file sources requires may
+            be disabled by the permission, `Disable AI Catalog Snapshots`.
         persist_data_after_ingestion: bool, optional
             If unset, uses the server default: True.
             If true, will enforce saving all data
@@ -323,6 +348,9 @@ class Dataset(APIObject):
         credential_data: dict, optional
             The credentials to authenticate with the database, to use instead of user/password or
             credential ID.
+        max_wait: int, optional
+            Time in seconds after which project creation is considered unsuccessful
+
 
         Returns
         -------
@@ -348,7 +376,9 @@ class Dataset(APIObject):
         upload_url = "{}fromDataSource/".format(cls._path)
         response = cls._client.post(upload_url, data=data)
 
-        new_dataset_location = wait_for_async_resolution(cls._client, response.headers["Location"])
+        new_dataset_location = wait_for_async_resolution(
+            cls._client, response.headers["Location"], max_wait
+        )
         return cls.from_location(new_dataset_location)
 
     @classmethod
@@ -773,7 +803,7 @@ class Dataset(APIObject):
         read_timeout: int, optional
             The maximum number of seconds to wait for the server to respond indicating that the
             initial upload is complete
-        max_wait : int, optional
+        max_wait: int, optional
             Time in seconds after which project creation is considered unsuccessful
 
         Returns
@@ -817,7 +847,13 @@ class Dataset(APIObject):
 
     @classmethod
     def create_version_from_in_memory_data(
-        cls, dataset_id, data_frame=None, records=None, categories=None
+        cls,
+        dataset_id,
+        data_frame=None,
+        records=None,
+        categories=None,
+        read_timeout=DEFAULT_TIMEOUT.UPLOAD,
+        max_wait=DEFAULT_MAX_WAIT,
     ):
         """
         A blocking call that creates a new Dataset version for a dataset from in-memory data.
@@ -838,6 +874,11 @@ class Dataset(APIObject):
         categories: list[string], optional
             An array of strings describing the intended use of the dataset. The
             current supported options are "TRAINING" and "PREDICTION".
+        read_timeout: int, optional
+            The maximum number of seconds to wait for the server to respond indicating that the
+            initial upload is complete
+        max_wait: int, optional
+            Time in seconds after which project creation is considered unsuccessful
 
         Returns
         -------
@@ -849,10 +890,16 @@ class Dataset(APIObject):
             buff = dataframe_to_buffer(data_frame)
         else:
             buff = list_of_records_to_buffer(records)
-        return cls.create_version_from_file(dataset_id, filelike=buff, categories=categories)
+        return cls.create_version_from_file(
+            dataset_id,
+            filelike=buff,
+            categories=categories,
+            read_timeout=read_timeout,
+            max_wait=max_wait,
+        )
 
     @classmethod
-    def create_version_from_url(cls, dataset_id, url, categories=None):
+    def create_version_from_url(cls, dataset_id, url, categories=None, max_wait=DEFAULT_MAX_WAIT):
         """
         A blocking call that creates a new Dataset from data stored at a url for a given dataset.
         Returns when the dataset has been successfully uploaded and processed.
@@ -868,6 +915,8 @@ class Dataset(APIObject):
         categories: list[string], optional
             An array of strings describing the intended use of the dataset. The
             current supported options are "TRAINING" and "PREDICTION".
+        max_wait: int, optional
+            Time in seconds after which project creation is considered unsuccessful
 
         Returns
         -------
@@ -882,7 +931,9 @@ class Dataset(APIObject):
         upload_url = "{}{}/versions/fromURL/".format(cls._path, dataset_id)
         response = cls._client.post(upload_url, data=data)
 
-        new_dataset_location = wait_for_async_resolution(cls._client, response.headers["Location"])
+        new_dataset_location = wait_for_async_resolution(
+            cls._client, response.headers["Location"], max_wait
+        )
         return cls.from_location(new_dataset_location)
 
     @classmethod
@@ -896,6 +947,7 @@ class Dataset(APIObject):
         credential_id=None,
         use_kerberos=None,
         credential_data=None,
+        max_wait=DEFAULT_MAX_WAIT,
     ):
         """
         A blocking call that creates a new Dataset from data stored at a DataSource.
@@ -927,6 +979,8 @@ class Dataset(APIObject):
         credential_data: dict, optional
             The credentials to authenticate with the database, to use instead of user/password or
             credential ID.
+        max_wait: int, optional
+            Time in seconds after which project creation is considered unsuccessful
 
         Returns
         -------
@@ -950,7 +1004,9 @@ class Dataset(APIObject):
         upload_url = "{}{}/versions/fromDataSource/".format(cls._path, dataset_id)
         response = cls._client.post(upload_url, data=data)
 
-        new_dataset_location = wait_for_async_resolution(cls._client, response.headers["Location"])
+        new_dataset_location = wait_for_async_resolution(
+            cls._client, response.headers["Location"], max_wait
+        )
         return cls.from_location(new_dataset_location)
 
 
@@ -1061,23 +1117,23 @@ class DatasetDetails(APIObject):
 
     _extra_fields = t.Dict(
         {
-            t.Key("data_engine_query_id", optional=True): t.String,
-            t.Key("data_source_id", optional=True): t.String,
-            t.Key("data_source_type"): t.String(allow_blank=True),
-            t.Key("description", optional=True): t.String,
+            t.Key("data_engine_query_id", optional=True): String,
+            t.Key("data_source_id", optional=True): String,
+            t.Key("data_source_type"): String(allow_blank=True),
+            t.Key("description", optional=True): String,
             t.Key("eda1_modification_date", optional=True): t.Call(
                 lambda s: dateutil.parser.parse(s)
             ),
-            t.Key("eda1_modifier_full_name", optional=True): t.String,
-            t.Key("error"): t.String(allow_blank=True),
-            t.Key("feature_count", optional=True): t.Int,
+            t.Key("eda1_modifier_full_name", optional=True): String,
+            t.Key("error"): String(allow_blank=True),
+            t.Key("feature_count", optional=True): Int,
             t.Key("feature_count_by_type", optional=True): t.List(
                 t.Call(lambda d: FeatureTypeCount(**d))
             ),
             t.Key("last_modification_date"): t.Call(lambda s: dateutil.parser.parse(s)),
-            t.Key("last_modifier_full_name"): t.String,
-            t.Key("tags", optional=True): t.List(t.String),
-            t.Key("uri"): t.String,
+            t.Key("last_modifier_full_name"): String,
+            t.Key("tags", optional=True): t.List(String),
+            t.Key("uri"): String,
         }
     )
 
