@@ -1,5 +1,6 @@
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.models.api_object import APIObject
 from datarobot.utils import datetime_to_string, encode_utf8_if_py2, from_api, parse_time
 
@@ -34,7 +35,7 @@ _accuracy_anomaly_over_time_plots_status_trafaret = t.Dict(
 
 _forecast_vs_actual_training_validation_status_trafaret = t.Dict(
     {
-        t.Key(underscorize(status), to_name=status, optional=True): t.List(t.Int)
+        t.Key(underscorize(status), to_name=status, optional=True): t.List(Int)
         for status in DATETIME_TREND_PLOTS_STATUS.ALL
     }
 ).ignore_extra("*")
@@ -52,7 +53,7 @@ _accuracy_over_time_plots_bin_trafaret = t.Dict(
         t.Key("end_date"): parse_time,
         t.Key("actual"): t.Float | t.Null,
         t.Key("predicted"): t.Float | t.Null,
-        t.Key("frequency"): t.Int | t.Null,
+        t.Key("frequency"): Int | t.Null,
     }
 ).ignore_extra("*")
 
@@ -64,7 +65,7 @@ _forecast_vs_actual_plots_bin_trafaret = t.Dict(
         t.Key("error"): t.Float | t.Null,
         t.Key("normalized_error"): t.Float | t.Null,
         t.Key("forecasts"): t.List(t.Float | t.Null),
-        t.Key("frequency"): t.Int | t.Null,
+        t.Key("frequency"): Int | t.Null,
     }
 ).ignore_extra("*")
 
@@ -73,7 +74,7 @@ _anomaly_over_time_plots_bin_trafaret = t.Dict(
         t.Key("start_date"): parse_time,
         t.Key("end_date"): parse_time,
         t.Key("predicted"): t.Float | t.Null,
-        t.Key("frequency"): t.Int | t.Null,
+        t.Key("frequency"): Int | t.Null,
     }
 ).ignore_extra("*")
 
@@ -92,7 +93,7 @@ _anomaly_over_time_plots_preview_bin_trafaret = t.Dict(
 
 
 _calendar_event_trafaret = t.Dict(
-    {t.Key("name"): t.String, t.Key("date"): parse_time, t.Key("series_id"): t.String | t.Null}
+    {t.Key("name"): String, t.Key("date"): parse_time, t.Key("series_id"): String | t.Null}
 ).ignore_extra("*")
 
 _statistics_trafaret = t.Dict({t.Key("durbin_watson"): t.Float | t.Null}).ignore_extra("*")
@@ -181,9 +182,9 @@ class AccuracyOverTimePlotsMetadata(DatetimeTrendPlotsMetadataObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
-            t.Key("forecast_distance"): t.Int | t.Null,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
+            t.Key("forecast_distance"): Int | t.Null,
             t.Key("resolutions"): t.List(t.Enum(*DATETIME_TREND_PLOTS_RESOLUTION.ALL)),
             t.Key("backtest_metadata"): t.List(_backtest_holdout_metadata_trafaret),
             t.Key("holdout_metadata"): _backtest_holdout_metadata_trafaret,
@@ -285,8 +286,8 @@ class AccuracyOverTimePlot(DatetimeTrendPlotsAPIObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("start_date"): parse_time,
             t.Key("end_date"): parse_time,
             t.Key("resolution"): t.Enum(*DATETIME_TREND_PLOTS_RESOLUTION.ALL),
@@ -365,8 +366,8 @@ class AccuracyOverTimePlotPreview(DatetimeTrendPlotsAPIObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("start_date"): parse_time,
             t.Key("end_date"): parse_time,
             t.Key("bins"): t.List(_datetime_trend_plots_preview_bin_trafaret),
@@ -445,8 +446,8 @@ class ForecastVsActualPlotsMetadata(DatetimeTrendPlotsMetadataObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("resolutions"): t.List(t.Enum(*DATETIME_TREND_PLOTS_RESOLUTION.ALL)),
             t.Key("backtest_metadata"): t.List(_backtest_holdout_metadata_trafaret),
             t.Key("holdout_metadata"): _backtest_holdout_metadata_trafaret,
@@ -544,9 +545,9 @@ class ForecastVsActualPlot(DatetimeTrendPlotsAPIObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
-            t.Key("forecast_distances"): t.List(t.Int),
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
+            t.Key("forecast_distances"): t.List(Int),
             t.Key("start_date"): parse_time,
             t.Key("end_date"): parse_time,
             t.Key("resolution"): t.Enum(*DATETIME_TREND_PLOTS_RESOLUTION.ALL),
@@ -624,8 +625,8 @@ class ForecastVsActualPlotPreview(DatetimeTrendPlotsAPIObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("start_date"): parse_time,
             t.Key("end_date"): parse_time,
             t.Key("bins"): t.List(_datetime_trend_plots_preview_bin_trafaret),
@@ -701,8 +702,8 @@ class AnomalyOverTimePlotsMetadata(DatetimeTrendPlotsMetadataObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("resolutions"): t.List(t.Enum(*DATETIME_TREND_PLOTS_RESOLUTION.ALL)),
             t.Key("backtest_metadata"): t.List(_backtest_holdout_metadata_trafaret),
             t.Key("holdout_metadata"): _backtest_holdout_metadata_trafaret,
@@ -788,8 +789,8 @@ class AnomalyOverTimePlot(DatetimeTrendPlotsAPIObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("start_date"): parse_time,
             t.Key("end_date"): parse_time,
             t.Key("resolution"): t.Enum(*DATETIME_TREND_PLOTS_RESOLUTION.ALL),
@@ -857,8 +858,8 @@ class AnomalyOverTimePlotPreview(DatetimeTrendPlotsAPIObject):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("prediction_threshold"): t.Float,
             t.Key("start_date"): parse_time,
             t.Key("end_date"): parse_time,
