@@ -7,6 +7,7 @@ import pandas as pd
 import pytz
 import trafaret as t
 
+from datarobot._compat import String
 from datarobot.enums import DEFAULT_MAX_WAIT
 from datarobot.models.api_object import APIObject
 from datarobot.models.custom_inference_image import CustomInferenceImage
@@ -53,17 +54,17 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
     _path = "deployments/"
     _default_prediction_server_converter = t.Dict(
         {
-            t.Key("id", optional=True): t.String(allow_blank=True),
-            t.Key("url", optional=True): t.String(allow_blank=True),
-            t.Key("datarobot-key", optional=True): t.String(allow_blank=True),
+            t.Key("id", optional=True): String(allow_blank=True),
+            t.Key("url", optional=True): String(allow_blank=True),
+            t.Key("datarobot-key", optional=True): String(allow_blank=True),
         }
     ).allow_extra("*")
     _model_converter = t.Dict(
         {
-            t.Key("id", optional=True): t.String(),
-            t.Key("type", optional=True): t.String(allow_blank=True),
-            t.Key("target_name", optional=True): t.String(allow_blank=True),
-            t.Key("project_id", optional=True): t.String(allow_blank=True),
+            t.Key("id", optional=True): String(),
+            t.Key("type", optional=True): String(allow_blank=True),
+            t.Key("target_name", optional=True): String(allow_blank=True),
+            t.Key("project_id", optional=True): String(allow_blank=True),
         }
     ).allow_extra("*")
     _capabilities = t.Dict(
@@ -75,28 +76,27 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
     _prediction_usage = t.Dict(
         {
             t.Key("daily_rates", optional=True): t.List(t.Float()),
-            t.Key("last_timestamp", optional=True): t.String
-            >> (lambda s: dateutil.parser.parse(s)),
+            t.Key("last_timestamp", optional=True): String >> (lambda s: dateutil.parser.parse(s)),
         }
     ).allow_extra("*")
     _health = t.Dict(
         {
-            t.Key("status", optional=True): t.String(allow_blank=True),
-            t.Key("message", optional=True): t.String(allow_blank=True),
-            t.Key("start_date", optional=True): t.String >> (lambda s: dateutil.parser.parse(s)),
-            t.Key("end_date", optional=True): t.String >> (lambda s: dateutil.parser.parse(s)),
+            t.Key("status", optional=True): String(allow_blank=True),
+            t.Key("message", optional=True): String(allow_blank=True),
+            t.Key("start_date", optional=True): String >> (lambda s: dateutil.parser.parse(s)),
+            t.Key("end_date", optional=True): String >> (lambda s: dateutil.parser.parse(s)),
         }
     ).allow_extra("*")
     _converter = t.Dict(
         {
-            t.Key("id"): t.String(),
-            t.Key("label", optional=True): t.String(allow_blank=True),
-            t.Key("description", optional=True): t.String(allow_blank=True) | t.Null(),
+            t.Key("id"): String(),
+            t.Key("label", optional=True): String(allow_blank=True),
+            t.Key("description", optional=True): String(allow_blank=True) | t.Null(),
             t.Key("default_prediction_server", optional=True): _default_prediction_server_converter,
             t.Key("model", optional=True): _model_converter,
             t.Key("capabilities", optional=True): _capabilities,
             t.Key("prediction_usage", optional=True): _prediction_usage,
-            t.Key("permissions", optional=True): t.List(t.String),
+            t.Key("permissions", optional=True): t.List(String),
             t.Key("service_health", optional=True): _health,
             t.Key("model_health", optional=True): _health,
             t.Key("accuracy_health", optional=True): _health,
@@ -1488,12 +1488,12 @@ class DeploymentListFilters(object):
         filters applied.
     """
 
-    role = attr.ib(default=None, converter=_check(t.String()))
-    service_health = attr.ib(default=None, converter=_check(t.List[t.String()]))
-    model_health = attr.ib(default=None, converter=_check(t.List[t.String()]))
-    accuracy_health = attr.ib(default=None, converter=_check(t.List[t.String()]))
-    execution_environment_type = attr.ib(default=None, converter=_check(t.List[t.String()]))
-    importance = attr.ib(default=None, converter=_check(t.List[t.String()]))
+    role = attr.ib(default=None, converter=_check(String()))
+    service_health = attr.ib(default=None, converter=_check(t.List[String()]))
+    model_health = attr.ib(default=None, converter=_check(t.List[String()]))
+    accuracy_health = attr.ib(default=None, converter=_check(t.List[String()]))
+    execution_environment_type = attr.ib(default=None, converter=_check(t.List[String()]))
+    importance = attr.ib(default=None, converter=_check(t.List[String()]))
 
     def construct_query_args(self):
         query_args = {}
