@@ -2,6 +2,7 @@ import pandas as pd
 from six.moves.urllib.parse import quote
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.enums import DEFAULT_MAX_WAIT
 from datarobot.models.api_object import APIObject
 from datarobot.models.pairwise_statistics import (
@@ -132,45 +133,45 @@ class Feature(APIObject, HasHistogram):
 
     _converter = t.Dict(
         {
-            t.Key("id"): t.Int,
-            t.Key("project_id"): t.String,
-            t.Key("name"): t.String,
-            t.Key("feature_type", optional=True): t.String,
+            t.Key("id"): Int,
+            t.Key("project_id"): String,
+            t.Key("name"): String,
+            t.Key("feature_type", optional=True): String,
             t.Key("importance", optional=True): t.Float,
             t.Key("low_information"): t.Bool,
-            t.Key("unique_count"): t.Int,
-            t.Key("na_count", optional=True): t.Int,
-            t.Key("date_format", optional=True): t.String,
-            t.Key("min", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("max", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("mean", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("median", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("std_dev", optional=True): t.String | t.Int | t.Float | t.Null,
+            t.Key("unique_count"): Int,
+            t.Key("na_count", optional=True): Int,
+            t.Key("date_format", optional=True): String,
+            t.Key("min", optional=True): String | Int | t.Float | t.Null,
+            t.Key("max", optional=True): String | Int | t.Float | t.Null,
+            t.Key("mean", optional=True): String | Int | t.Float | t.Null,
+            t.Key("median", optional=True): String | Int | t.Float | t.Null,
+            t.Key("std_dev", optional=True): String | Int | t.Float | t.Null,
             t.Key("time_series_eligible"): t.Bool,
-            t.Key("time_series_eligibility_reason"): t.String,
-            t.Key("time_step", optional=True): t.Int,
-            t.Key("time_unit", optional=True): t.String,
-            t.Key("target_leakage", optional=True): t.String,
-            t.Key("feature_lineage_id", optional=True): t.String | t.Null,
+            t.Key("time_series_eligibility_reason"): String,
+            t.Key("time_step", optional=True): Int,
+            t.Key("time_unit", optional=True): String,
+            t.Key("target_leakage", optional=True): String,
+            t.Key("feature_lineage_id", optional=True): String | t.Null,
             t.Key("key_summary", optional=True): t.List(
                 t.Dict(
                     {
-                        t.Key("key"): t.String(allow_blank=True),
+                        t.Key("key"): String(allow_blank=True),
                         t.Key("summary"): t.Dict(
                             {
-                                t.Key("max"): t.Float | t.Int,
-                                t.Key("min"): t.Float | t.Int,
-                                t.Key("mean"): t.Float | t.Int,
-                                t.Key("median"): t.Float | t.Int,
-                                t.Key("std_dev"): t.Float | t.Int,
-                                t.Key("pct_rows"): t.Float | t.Int,
+                                t.Key("max"): t.Float | Int,
+                                t.Key("min"): t.Float | Int,
+                                t.Key("mean"): t.Float | Int,
+                                t.Key("median"): t.Float | Int,
+                                t.Key("std_dev"): t.Float | Int,
+                                t.Key("pct_rows"): t.Float | Int,
                             }
                         ).allow_extra("*"),
                     }
                 ).allow_extra("*")
             ),
             t.Key("multilabel_insights", optional=True): t.Dict(
-                {t.Key("multilabel_insights_key"): t.String}
+                {t.Key("multilabel_insights_key"): String}
             ).allow_extra("*"),
         }
     ).allow_extra("*")
@@ -298,13 +299,13 @@ class Feature(APIObject, HasHistogram):
             response = self._client.get(retrieve_url)
             response_schema = t.Dict(
                 {
-                    t.Key("datetimePartitionColumn"): t.String(),
+                    t.Key("datetimePartitionColumn"): String(),
                     t.Key("detectedMultiseriesIdColumns"): t.List(
                         t.Dict(
                             {
-                                t.Key("multiseriesIdColumns"): t.List(t.String()),
-                                t.Key("timeUnit"): t.String(),
-                                t.Key("timeStep"): t.Int(),
+                                t.Key("multiseriesIdColumns"): t.List(String()),
+                                t.Key("timeUnit"): String(),
+                                t.Key("timeStep"): Int(),
                             }
                         ).ignore_extra("*")
                     ),
@@ -386,12 +387,12 @@ class Feature(APIObject, HasHistogram):
             response = self._client.get(retrieve_url)
             response_schema = t.Dict(
                 {
-                    t.Key("multiseriesId"): t.String(),
+                    t.Key("multiseriesId"): String(),
                     t.Key("crossSeriesGroupByColumns"): t.List(
                         t.Dict(
                             {
-                                t.Key("name"): t.String(),
-                                t.Key("eligibility"): t.String(),
+                                t.Key("name"): String(),
+                                t.Key("eligibility"): String(),
                                 t.Key("isEligible"): t.Bool(),
                             }
                         ).ignore_extra("*")
@@ -621,32 +622,33 @@ class ModelingFeature(APIObject, HasHistogram):
 
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("name"): t.String,
-            t.Key("feature_type", optional=True): t.String,
+            t.Key("project_id"): String,
+            t.Key("name"): String,
+            t.Key("feature_type", optional=True): String,
             t.Key("importance", optional=True): t.Float,
             t.Key("low_information"): t.Bool,
-            t.Key("unique_count"): t.Int,
-            t.Key("na_count", optional=True): t.Int,
-            t.Key("date_format", optional=True): t.String,
-            t.Key("min", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("max", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("mean", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("median", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("std_dev", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("parent_feature_names"): t.List(t.String),
+            t.Key("unique_count"): Int,
+            t.Key("na_count", optional=True): Int,
+            t.Key("date_format", optional=True): String,
+            t.Key("min", optional=True): String | Int | t.Float | t.Null,
+            t.Key("max", optional=True): String | Int | t.Float | t.Null,
+            t.Key("mean", optional=True): String | Int | t.Float | t.Null,
+            t.Key("median", optional=True): String | Int | t.Float | t.Null,
+            t.Key("std_dev", optional=True): String | Int | t.Float | t.Null,
+            t.Key("parent_feature_names"): t.List(String),
+            t.Key("is_restored_after_reduction", optional=True): t.Bool,
             t.Key("key_summary", optional=True): t.List(
                 t.Dict(
                     {
-                        t.Key("key"): t.String(allow_blank=True),
+                        t.Key("key"): String(allow_blank=True),
                         t.Key("summary"): t.Dict(
                             {
-                                t.Key("max"): t.Float | t.Int,
-                                t.Key("min"): t.Float | t.Int,
-                                t.Key("mean"): t.Float | t.Int,
-                                t.Key("median"): t.Float | t.Int,
-                                t.Key("std_dev"): t.Float | t.Int,
-                                t.Key("pct_rows"): t.Float | t.Int,
+                                t.Key("max"): t.Float | Int,
+                                t.Key("min"): t.Float | Int,
+                                t.Key("mean"): t.Float | Int,
+                                t.Key("median"): t.Float | Int,
+                                t.Key("std_dev"): t.Float | Int,
+                                t.Key("pct_rows"): t.Float | Int,
                             }
                         ).allow_extra("*"),
                     }
@@ -672,6 +674,7 @@ class ModelingFeature(APIObject, HasHistogram):
         std_dev=None,
         parent_feature_names=None,
         key_summary=None,
+        is_restored_after_reduction=None,
     ):
         self.project_id = project_id
         self.name = name
@@ -688,6 +691,7 @@ class ModelingFeature(APIObject, HasHistogram):
         self.std_dev = std_dev
         self.parent_feature_names = parent_feature_names
         self.key_summary = key_summary
+        self.is_restored_after_reduction = is_restored_after_reduction
 
     def __repr__(self):
         return encode_utf8_if_py2(u"ModelingFeature({})".format(self.name))
@@ -788,26 +792,26 @@ class DatasetFeature(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("id") >> "id_": t.Int,
-            t.Key("dataset_id"): t.String,
-            t.Key("dataset_version_id"): t.String,
-            t.Key("name"): t.String,
-            t.Key("feature_type", optional=True): t.String,
+            t.Key("id") >> "id_": Int,
+            t.Key("dataset_id"): String,
+            t.Key("dataset_version_id"): String,
+            t.Key("name"): String,
+            t.Key("feature_type", optional=True): String,
             t.Key("low_information", optional=True): t.Bool,
-            t.Key("unique_count", optional=True): t.Int,
-            t.Key("na_count", optional=True): t.Int,
-            t.Key("date_format", optional=True): t.String,
-            t.Key("min", optional=True) >> "min_": t.String | t.Int | t.Float | t.Null,
-            t.Key("max", optional=True) >> "max_": t.String | t.Int | t.Float | t.Null,
-            t.Key("mean", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("median", optional=True): t.String | t.Int | t.Float | t.Null,
-            t.Key("std_dev", optional=True): t.String | t.Int | t.Float | t.Null,
+            t.Key("unique_count", optional=True): Int,
+            t.Key("na_count", optional=True): Int,
+            t.Key("date_format", optional=True): String,
+            t.Key("min", optional=True) >> "min_": String | Int | t.Float | t.Null,
+            t.Key("max", optional=True) >> "max_": String | Int | t.Float | t.Null,
+            t.Key("mean", optional=True): String | Int | t.Float | t.Null,
+            t.Key("median", optional=True): String | Int | t.Float | t.Null,
+            t.Key("std_dev", optional=True): String | Int | t.Float | t.Null,
             t.Key("time_series_eligible", optional=True): t.Bool,
-            t.Key("time_series_eligibility_reason", optional=True): t.String,
-            t.Key("time_step", optional=True): t.Int,
-            t.Key("time_unit", optional=True): t.String,
-            t.Key("target_leakage", optional=True): t.String,
-            t.Key("target_leakage_reason", optional=True): t.String,
+            t.Key("time_series_eligibility_reason", optional=True): String,
+            t.Key("time_step", optional=True): Int,
+            t.Key("time_unit", optional=True): String,
+            t.Key("target_leakage", optional=True): String,
+            t.Key("target_leakage_reason", optional=True): String,
         }
     ).allow_extra("*")
 
@@ -917,8 +921,8 @@ class BaseFeatureHistogram(APIObject):
             t.Key("plot"): t.List(
                 t.Dict(
                     {
-                        t.Key("label"): t.String,
-                        t.Key("count"): t.Int | t.Float,
+                        t.Key("label"): String,
+                        t.Key("count"): Int | t.Float,
                         t.Key("target", default=None): t.Float | t.Null,
                     }
                 )
@@ -1052,14 +1056,14 @@ class InteractionFeature(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("rows"): t.Int,
-            t.Key("source_columns"): t.List(t.String, min_length=2, max_length=2),
+            t.Key("rows"): Int,
+            t.Key("source_columns"): t.List(String, min_length=2, max_length=2),
             t.Key("bars"): t.List(
                 t.Dict(
                     {
-                        t.Key("column_name"): t.String,
+                        t.Key("column_name"): String,
                         t.Key("counts"): t.List(
-                            t.Dict({t.Key("value"): t.String, t.Key("count"): t.Int}),
+                            t.Dict({t.Key("value"): String, t.Key("count"): Int}),
                             min_length=2,
                             max_length=2,
                         ),
@@ -1069,9 +1073,9 @@ class InteractionFeature(APIObject):
             t.Key("bubbles"): t.List(
                 t.Dict(
                     {
-                        t.Key("count"): t.Int,
+                        t.Key("count"): Int,
                         t.Key("source_data"): t.List(
-                            t.Dict({t.Key("value"): t.String, t.Key("column_name"): t.String}),
+                            t.Dict({t.Key("value"): String, t.Key("column_name"): String}),
                             min_length=2,
                             max_length=2,
                         ),
@@ -1193,21 +1197,21 @@ class FeatureLineage(APIObject):
     """
 
     _join_table_trafaret = t.Dict(
-        {t.Key("datasteps"): t.List(t.Int(gte=1)), t.Key("columns"): t.List(t.String)}
+        {t.Key("datasteps"): t.List(Int(gte=1)), t.Key("columns"): t.List(String)}
     )
 
     _duration_trafaret = t.Dict(
         {
-            t.Key("duration"): t.Int,
-            t.Key("time_unit"): t.String,
+            t.Key("duration"): Int,
+            t.Key("time_unit"): String,
             t.Key("is_original", optional=True): t.Bool | t.Null,
         }
     )
 
     _columns_trafaret = t.Dict(
         {
-            t.Key("name"): t.String,
-            t.Key("data_type"): t.String,
+            t.Key("name"): String,
+            t.Key("data_type"): String,
             t.Key("is_input"): t.Bool,
             t.Key("is_cutoff", optional=True): t.Bool,
         }
@@ -1218,14 +1222,14 @@ class FeatureLineage(APIObject):
             t.Key("steps"): t.List(
                 t.Dict(
                     {
-                        t.Key("id"): t.Int(gte=0) | t.Null,
+                        t.Key("id"): Int(gte=0) | t.Null,
                         t.Key("step_type"): t.Regexp(regexp="data|join|generatedColumn|action"),
-                        t.Key("parents"): t.List(t.Int),
-                        t.Key("name", optional=True): t.String,
-                        t.Key("description", optional=True): t.String | t.Null,
-                        t.Key("data_type", optional=True): t.String | t.Null,
-                        t.Key("catalog_id", optional=True): t.String | t.Null,
-                        t.Key("catalog_version_id", optional=True): t.String | t.Null,
+                        t.Key("parents"): t.List(Int),
+                        t.Key("name", optional=True): String,
+                        t.Key("description", optional=True): String | t.Null,
+                        t.Key("data_type", optional=True): String | t.Null,
+                        t.Key("catalog_id", optional=True): String | t.Null,
+                        t.Key("catalog_version_id", optional=True): String | t.Null,
                         t.Key("columns", optional=True): t.List(_columns_trafaret),
                         t.Key("is_time_aware", optional=True): t.Bool,
                         t.Key("join_info", optional=True): t.Dict(
@@ -1235,7 +1239,7 @@ class FeatureLineage(APIObject):
                                 t.Key("right_table"): _join_table_trafaret,
                             }
                         ).ignore_extra("*"),
-                        t.Key("group_by", optional=True): t.List(t.String) | t.Null,
+                        t.Key("group_by", optional=True): t.List(String) | t.Null,
                         t.Key("time_info", optional=True): t.Dict(
                             {
                                 t.Key("latest", optional=True): _duration_trafaret,
@@ -1302,16 +1306,16 @@ class MulticategoricalHistogram(APIObject):
 
     _converter = t.Dict(
         {
-            t.Key("feature_name"): t.String,
+            t.Key("feature_name"): String,
             t.Key("histogram"): t.List(
                 t.Dict(
                     {
-                        t.Key("label"): t.String,
+                        t.Key("label"): String,
                         t.Key("plot"): t.List(
                             t.Dict(
                                 {
-                                    t.Key("label_relevance"): t.Int,
-                                    t.Key("row_count"): t.Int,
+                                    t.Key("label_relevance"): Int,
+                                    t.Key("row_count"): Int,
                                     t.Key("row_pct"): t.Float,
                                 }
                             ).allow_extra("*")
