@@ -25,6 +25,7 @@ on the concrete classes.
 """
 import trafaret as t
 
+from datarobot._compat import Int, String
 from datarobot.models.feature_fit import FeatureFit
 from datarobot.models.shap_impact import ShapImpact
 from datarobot.models.validators import feature_impact_trafaret, single_feature_impact_trafaret
@@ -56,7 +57,7 @@ class AbstractJob(object):
     _client = staticproperty(get_client)
     _converter_common = t.Dict(
         {
-            t.Key("id", optional=True): t.Int,
+            t.Key("id", optional=True): Int,
             t.Key("status", optional=True): t.Enum(
                 QUEUE_STATUS.ABORTED,
                 QUEUE_STATUS.COMPLETED,
@@ -64,8 +65,8 @@ class AbstractJob(object):
                 QUEUE_STATUS.INPROGRESS,
                 QUEUE_STATUS.QUEUE,
             ),
-            t.Key("project_id", optional=True): t.String,
-            t.Key("model_id", optional=True): t.String,
+            t.Key("project_id", optional=True): String,
+            t.Key("model_id", optional=True): String,
             t.Key("is_blocked"): t.Bool,
         }
     )
@@ -293,7 +294,7 @@ class Job(AbstractJob):
     """
 
     _converter_extra = t.Dict(
-        {t.Key("job_type", optional=True) >> "job_type": t.String, t.Key("url") >> "url": t.String}
+        {t.Key("job_type", optional=True) >> "job_type": String, t.Key("url") >> "url": String}
     )
 
     def __init__(self, data, completed_resource_url=None):
