@@ -3,10 +3,12 @@ from datetime import datetime
 import pandas as pd
 import trafaret as t
 
+from datarobot._compat import Int, String
+
 from ..utils import encode_utf8_if_py2, get_id_from_response
 from .api_object import APIObject
 
-int_float_string = t.Type(int) | t.Type(float) | t.String(allow_blank=True)
+int_float_string = t.Type(int) | t.Type(float) | String(allow_blank=True)
 
 prediction_values_trafaret = t.Dict(
     {t.Key("label"): int_float_string, t.Key("value"): t.Float}
@@ -15,16 +17,16 @@ prediction_values_trafaret = t.Dict(
 prediction_explanations_entry_trafaret = t.Dict(
     {
         t.Key("label"): int_float_string,
-        t.Key("feature"): t.String,
+        t.Key("feature"): String,
         t.Key("feature_value"): int_float_string,
         t.Key("strength"): t.Float,
-        t.Key("qualitative_strength"): t.String,
+        t.Key("qualitative_strength"): String,
     }
 ).ignore_extra("*")
 
 prediction_explanations_trafaret = t.Dict(
     {
-        t.Key("row_id"): t.Int,
+        t.Key("row_id"): Int,
         t.Key("prediction"): int_float_string,
         t.Key("adjusted_prediction", optional=True): int_float_string,
         t.Key("prediction_values"): t.List(prediction_values_trafaret),
@@ -51,8 +53,8 @@ class PredictionExplanationsInitialization(APIObject):
     _path_template = "projects/{}/models/{}/predictionExplanationsInitialization/"
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("prediction_explanations_sample"): t.List(prediction_explanations_trafaret),
         }
     ).allow_extra("*")
@@ -172,16 +174,16 @@ class PredictionExplanations(APIObject):
     _expls_path_template = "projects/{}/predictionExplanations/"
     _converter = t.Dict(
         {
-            t.Key("id"): t.String,
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
-            t.Key("dataset_id"): t.String,
-            t.Key("max_explanations"): t.Int,
+            t.Key("id"): String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
+            t.Key("dataset_id"): String,
+            t.Key("max_explanations"): Int,
             t.Key("threshold_low", optional=True): t.Float,
             t.Key("threshold_high", optional=True): t.Float,
-            t.Key("num_columns"): t.Int,
+            t.Key("num_columns"): Int,
             t.Key("finish_time"): t.Float,
-            t.Key("prediction_explanations_location"): t.String,
+            t.Key("prediction_explanations_location"): String,
         }
     ).allow_extra("*")
 
@@ -617,13 +619,13 @@ class PredictionExplanationsPage(APIObject):
     _path_template = "projects/{}/predictionExplanations/"
     _converter = t.Dict(
         {
-            t.Key("id"): t.String,
-            t.Key("count"): t.Int,
-            t.Key("previous", optional=True): t.String(),
-            t.Key("next", optional=True): t.String(),
+            t.Key("id"): String,
+            t.Key("count"): Int,
+            t.Key("previous", optional=True): String(),
+            t.Key("next", optional=True): String(),
             t.Key("data"): t.List(prediction_explanations_trafaret),
             t.Key("prediction_explanations_record_location"): t.URL,
-            t.Key("adjustment_method", default="N/A"): t.String(),
+            t.Key("adjustment_method", default="N/A"): String(),
         }
     ).allow_extra("*")
 
