@@ -5,6 +5,8 @@ from datetime import datetime
 import pandas as pd
 import trafaret as t
 
+from datarobot._compat import Int, String
+
 from ..utils import deprecated, encode_utf8_if_py2, get_id_from_response
 from .api_object import APIObject
 from .prediction_explanations import (
@@ -12,11 +14,11 @@ from .prediction_explanations import (
     prediction_values_trafaret,
 )
 
-int_float_string = t.Type(int) | t.Type(float) | t.String(allow_blank=True)
+int_float_string = t.Type(int) | t.Type(float) | String(allow_blank=True)
 
 reason_code_trafaret = t.Dict(
     {
-        t.Key("row_id"): t.Int,
+        t.Key("row_id"): Int,
         t.Key("prediction"): int_float_string,
         t.Key("adjusted_prediction", optional=True): int_float_string,
         t.Key("prediction_values"): t.List(prediction_values_trafaret),
@@ -43,8 +45,8 @@ class ReasonCodesInitialization(APIObject):
     _path_template = "projects/{}/models/{}/reasonCodesInitialization/"
     _converter = t.Dict(
         {
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
             t.Key("reason_codes_sample"): t.List(reason_code_trafaret),
         }
     ).allow_extra("*")
@@ -166,16 +168,16 @@ class ReasonCodes(APIObject):
     _codes_path_template = "projects/{}/reasonCodes/"
     _converter = t.Dict(
         {
-            t.Key("id"): t.String,
-            t.Key("project_id"): t.String,
-            t.Key("model_id"): t.String,
-            t.Key("dataset_id"): t.String,
-            t.Key("max_codes"): t.Int,
+            t.Key("id"): String,
+            t.Key("project_id"): String,
+            t.Key("model_id"): String,
+            t.Key("dataset_id"): String,
+            t.Key("max_codes"): Int,
             t.Key("threshold_low", optional=True): t.Float,
             t.Key("threshold_high", optional=True): t.Float,
-            t.Key("num_columns"): t.Int,
+            t.Key("num_columns"): Int,
             t.Key("finish_time"): t.Float,
-            t.Key("reason_codes_location"): t.String,
+            t.Key("reason_codes_location"): String,
         }
     ).allow_extra("*")
 
@@ -607,13 +609,13 @@ class ReasonCodesPage(APIObject):
     _path_template = "projects/{}/reasonCodes/"
     _converter = t.Dict(
         {
-            t.Key("id"): t.String,
-            t.Key("count"): t.Int,
-            t.Key("previous", optional=True): t.String(),
-            t.Key("next", optional=True): t.String(),
+            t.Key("id"): String,
+            t.Key("count"): Int,
+            t.Key("previous", optional=True): String(),
+            t.Key("next", optional=True): String(),
             t.Key("data"): t.List(reason_code_trafaret),
             t.Key("reason_codes_record_location"): t.URL,
-            t.Key("adjustment_method", default="N/A"): t.String(),
+            t.Key("adjustment_method", default="N/A"): String(),
         }
     ).allow_extra("*")
 
