@@ -6,6 +6,7 @@ from six.moves.urllib_parse import parse_qs, urlparse
 import trafaret as t
 
 from datarobot import enums, errors
+from datarobot._compat import Int, String
 
 from ..utils import from_api
 from .api_object import APIObject
@@ -24,7 +25,7 @@ class RowsIterator(object):
     """
 
     _trafaret = t.Dict(
-        {t.Key("data"): t.List(t.Dict().allow_extra("*")), t.Key("next"): t.String | t.Null}
+        {t.Key("data"): t.List(t.Dict().allow_extra("*")), t.Key("next"): String | t.Null}
     ).allow_extra("*")
 
     def __init__(self, client, path, limit=None):
@@ -199,25 +200,25 @@ class TrainingPredictionsIterator(RowsIterator):
 
     _row_trafaret = t.Dict(
         {
-            t.Key("row_id"): t.Int(),
-            t.Key("partition_id"): t.String() | t.Float(),
-            t.Key("prediction"): t.Float() | t.String(),
+            t.Key("row_id"): Int(),
+            t.Key("partition_id"): String() | t.Float(),
+            t.Key("prediction"): t.Float() | String(),
             t.Key("prediction_values"): t.List(
-                t.Dict({t.Key("label"): t.Float | t.String, t.Key("value"): t.Float}).ignore_extra(
+                t.Dict({t.Key("label"): t.Float | String, t.Key("value"): t.Float}).ignore_extra(
                     "*"
                 )
             ),
-            t.Key("timestamp", default=None): t.String | t.Null,
-            t.Key("forecast_point", default=None): t.String | t.Null,
-            t.Key("forecast_distance", default=None): t.Int | t.Null,
-            t.Key("series_id", default=None): t.String | t.Int | t.Null,
+            t.Key("timestamp", default=None): String | t.Null,
+            t.Key("forecast_point", default=None): String | t.Null,
+            t.Key("forecast_distance", default=None): Int | t.Null,
+            t.Key("series_id", default=None): String | Int | t.Null,
             t.Key("prediction_explanations", default=None): t.List(
                 t.Dict(
                     {
-                        t.Key("feature"): t.String(),
-                        t.Key("feature_value"): t.String(),
+                        t.Key("feature"): String(),
+                        t.Key("feature_value"): String(),
                         t.Key("strength"): t.Float(),
-                        t.Key("label"): t.Float() | t.String(),
+                        t.Key("label"): t.Float() | String(),
                     }
                 )
             )
@@ -228,7 +229,7 @@ class TrainingPredictionsIterator(RowsIterator):
                     t.Key("shap_remaining_total"): t.Float(),
                     t.Key("warnings", optional=True): t.Dict(
                         {
-                            t.Key("mismatch_row_count"): t.Int(),
+                            t.Key("mismatch_row_count"): Int(),
                             t.Key("max_normalized_mismatch"): t.Float(),
                         }
                     ),
@@ -421,17 +422,17 @@ class TrainingPredictions(APIObject):
                 t.Key("data"): t.List(
                     t.Dict(
                         {
-                            t.Key("url"): t.String(),
-                            t.Key("model_id"): t.String(),
-                            t.Key("data_subset"): t.String(),
-                            t.Key("explanation_algorithm", optional=True): t.String() | t.Null(),
-                            t.Key("max_explanations", optional=True): t.Int() | t.Null(),
+                            t.Key("url"): String(),
+                            t.Key("model_id"): String(),
+                            t.Key("data_subset"): String(),
+                            t.Key("explanation_algorithm", optional=True): String() | t.Null(),
+                            t.Key("max_explanations", optional=True): Int() | t.Null(),
                             t.Key("shap_warnings", optional=True): t.Dict(
                                 {
-                                    t.Key("partition_name"): t.String(),
+                                    t.Key("partition_name"): String(),
                                     t.Key("value"): t.Dict(
                                         {
-                                            t.Key("mismatch_row_count"): t.Int(),
+                                            t.Key("mismatch_row_count"): Int(),
                                             t.Key("max_normalized_mismatch"): t.Float(),
                                         }
                                     ),
