@@ -8,7 +8,8 @@ from pandas.testing import assert_frame_equal
 import pytest
 import responses
 
-from datarobot import DatetimeModel, enums
+from datarobot import DatetimeModel, enums, Model
+from datarobot.errors import ClientError
 from tests.utils import request_body_to_json
 
 
@@ -241,6 +242,26 @@ def train_request_frozen_datetime_with_dates(
     assert mod_job.sample_pct is None
 
 
+@responses.activate
+def test_request_frozen_datetime_with_end_date_and_duration(
+    datetime_model, project_url, datetime_model_job_server_data
+):
+    # Here we test a bug which was uncovered by accident - when training_end_date and no
+    # training_start_date is passed in, we should pass the request to API, and it should fail on
+    # BE side.
+    responses.add(
+        responses.POST, "{}frozenDatetimeModels/".format(project_url), body="", status=422,
+    )
+
+    with pytest.raises(ClientError):
+        datetime_model.request_frozen_datetime_model(
+            training_duration="some duration",
+            training_end_date=datetime.now(),
+            time_window_sample_pct=40,
+            sampling_method="latest",
+        )
+
+
 @responses.activate
 def test_score_backtests(base_job_running_server_data, datetime_model, project_url):
     job_body = dict(base_job_running_server_data, jobType=enums.JOB_TYPE.MODEL)
@@ -561,3 +582,26 @@ def test_compute_datetime_trend_plots(unittest_endpoint, datetime_model, project
         "forecastDistanceStart": 1,
         "forecastDistanceEnd": 5,
     }
+
+
+@responses.activate
+def test_retrieved_model_is_of_datetime_model_from_model_instance(
+    datetime_project_server_data, datetime_start_end_model_server_data, project_url,
+):
+    project_id = datetime_start_end_model_server_data["projectId"]
+    model_id = datetime_start_end_model_server_data["id"]
+
+    responses.add(
+        responses.GET, project_url, status=200, json=datetime_project_server_data,
+    )
+    responses.add(
+        responses.GET,
+        "{}datetimeModels/{}/".format(project_url, model_id),
+        status=200,
+        json=datetime_start_end_model_server_data,
+    )
+
+    model = Model.get(project=project_id, model_id=model_id)
+    assert isinstance(model, DatetimeModel)
+    assert model.effective_feature_derivation_window_start == -120
+    assert model.effective_feature_derivation_window_end == 0
