@@ -1,3 +1,4 @@
+from copy import deepcopy
 import json
 
 import pytest
@@ -5,6 +6,8 @@ import responses
 from six.moves.urllib.parse import urljoin
 
 from datarobot import enums
+from datarobot.enums import CUSTOM_MODEL_TARGET_TYPE
+from tests.model.utils import change_response_value
 
 
 @pytest.fixture
@@ -202,11 +205,25 @@ def feature_impact_completed_response(
 
 @pytest.fixture
 def feature_impact_previously_ran_response(project_url, model_id, job_id):
+    return _feature_impact_previously_ran_response(project_url, model_id, job_id)
+
+
+@pytest.fixture
+def feature_impact_previously_ran_response__no_job_id(project_url, model_id):
+    return _feature_impact_previously_ran_response(
+        project_url,
+        model_id,
+        message="Feature Impact has been computed for this model.",
+        job_id=None,
+    )
+
+
+def _feature_impact_previously_ran_response(project_url, model_id, job_id, message=None):
     """
     Loads a response that the given model has already ran its feature impact
      """
     body = {
-        "message": "Feature Impact is in progress for this model.",
+        "message": message or "Feature Impact is in progress for this model.",
         "errorName": "JobAlreadyAdded",
         "jobId": job_id,
     }
@@ -491,3 +508,162 @@ def shap_impact_previously_ran_response(project_url, model_id, job_id, job_url):
         content_type="application/json",
         adding_headers={"Location": job_url},
     )
+
+
+# CustomTask and CustomTaskVersion
+
+
+@pytest.fixture
+def custom_task_id():
+    return "60dcbf0e8cd36258f9f5fff7"
+
+
+@pytest.fixture
+def custom_task_version_id():
+    return "60dcbf2b8cd36258f9f5fff8"
+
+
+@pytest.fixture
+def custom_task_version(custom_task_version_id, custom_task_id):
+    return {
+        "id": custom_task_version_id,
+        "customTaskId": custom_task_id,
+        "created": "abc",
+        "description": "this task is the coolest",
+        "items": [],
+        "isFrozen": True,
+        "versionMajor": 1,
+        "versionMinor": 2,
+        "label": "1.2",
+        "trainingHistory": [],
+    }
+
+
+@pytest.fixture
+def workspace_items():
+    return [
+        {
+            "fileSource": "local",
+            "workspaceId": "60abd24fc3d97e6f5f732575",
+            "filePath": "custom.py",
+            "storagePath": "workspace/60abd24fc3/custom.py",
+            "repositoryLocation": None,
+            "repositoryName": None,
+            "repositoryFilePath": None,
+            "ref": None,
+            "commitSha": None,
+            "id": "60abd2abb66ce93dc37324d2",
+            "created": "2021-05-24T16:22:03.423629Z",
+            "fileName": "custom.py",
+        },
+        {
+            "fileSource": "local",
+            "workspaceId": "60abd24fc3d97e6f5f732575",
+            "filePath": "createPipeline.py",
+            "storagePath": "workspace/60abd24fc3/createPipeline.py",
+            "repositoryLocation": "some location",
+            "repositoryName": "erics-awesome-repo",
+            "repositoryFilePath": "x/y.py",
+            "ref": "no idea",
+            "commitSha": "123abc",
+            "id": "60abd2abb66ce93dc37324d3",
+            "created": "2021-05-24T16:22:03.423995Z",
+            "fileName": "createPipeline.py",
+        },
+    ]
+
+
+@pytest.fixture
+def training_history():
+    return [
+        {"projectId": "def", "modelId": "abc"},
+        {"projectId": "ghi", "modelId": "jkl"},
+    ]
+
+
+@pytest.fixture
+def custom_task_version_with_optional_values(
+    custom_task_version, workspace_items, training_history
+):
+    new_task_version = deepcopy(custom_task_version)
+    new_task_version.update(
+        {
+            "baseEnvironmentVersionId": "mno",
+            "baseEnvironmentId": "pqr",
+            "dependencies": [
+                {
+                    "packageName": "pandas",
+                    "constraints": [{"constraintType": ">=", "version": "1.0"}],
+                    "line": "pandas >= 1.0",
+                    "lineNumber": 1,
+                }
+            ],
+            "items": workspace_items,
+            "trainingHistory": training_history,
+            "requiredMetadata": {"hello": "world"},
+            "requiredMetadataValues": [{"fieldName": "hello", "value": "world"}],
+        }
+    )
+    return new_task_version
+
+
+@pytest.fixture
+def custom_task_version_response_json(custom_task_version_with_optional_values):
+    return deepcopy(custom_task_version_with_optional_values)
+
+
+@pytest.fixture
+def custom_task_version_list_response(custom_task_version_response_json):
+    second_version = {
+        k: change_response_value(v) for k, v in custom_task_version_response_json.items()
+    }
+
+    return {
+        "count": 2,
+        "totalCount": 2,
+        "next": None,
+        "data": [custom_task_version_response_json, second_version],
+    }
+
+
+@pytest.fixture
+def custom_task(custom_task_id):
+    return {
+        "created": "10-10-2020",
+        "createdBy": "a froody dude",
+        "deploymentsCount": 1,
+        "description": "there's some stuff",
+        "id": custom_task_id,
+        "language": "python",
+        "name": "the coolest model",
+        "targetType": CUSTOM_MODEL_TARGET_TYPE.BINARY,
+        "updated": "12-12-3030",
+        "latestVersion": None,
+        "customModelType": "training",
+    }
+
+
+@pytest.fixture
+def custom_task_with_optional_values(custom_task, custom_task_version_with_optional_values):
+    full_task = deepcopy(custom_task)
+    full_task["latestVersion"] = deepcopy(custom_task_version_with_optional_values)
+    full_task["calibratePredictions"] = False
+    return full_task
+
+
+@pytest.fixture
+def custom_task_response_json(custom_task_with_optional_values):
+    return deepcopy(custom_task_with_optional_values)
+
+
+@pytest.fixture
+def custom_task_list_response(custom_task_response_json):
+    second = {k: change_response_value(v) for k, v in custom_task_response_json.items()}
+    second["latestVersion"] = None
+
+    return {
+        "count": 2,
+        "totalCount": 2,
+        "next": None,
+        "data": [custom_task_response_json, second],
+    }
