@@ -6,7 +6,7 @@ import pytest
 import responses
 
 from datarobot import CustomInferenceModel, TARGET_TYPE
-from datarobot.enums import CUSTOM_MODEL_TARGET_TYPE, CUSTOM_TASK_TYPE
+from datarobot.enums import CUSTOM_MODEL_TARGET_TYPE
 from datarobot.utils import underscorize
 from tests.model.utils import assert_custom_model_version
 
@@ -53,7 +53,7 @@ def mocked_inference_model_with_deprecated_target_support(mocked_inference_model
     return model
 
 
-def assert_custom_model_common(model, model_json, custom_task=False):
+def assert_custom_model_common(model, model_json):
     assert model.id == model_json["id"]
     assert model.name == model_json["name"]
     assert model.description == model_json["description"]
@@ -78,10 +78,6 @@ def assert_custom_model_common(model, model_json, custom_task=False):
     assert model.updated_at == model_json["updated"]
     assert model.created_at == model_json["created"]
 
-    if custom_task:
-        if model.task_type == CUSTOM_TASK_TYPE.TRANSFORM:
-            assert model_json["targetType"] == CUSTOM_TASK_TYPE.TRANSFORM
-
 
 def assert_inference_model(model, model_json):
     assert_custom_model_common(model, model_json)
