@@ -4,13 +4,15 @@ import json
 import os
 import uuid
 
+import mock
 import pytest
 from requests_toolbelt import MultipartEncoder
 import responses
 
 from datarobot import CustomModelVersion
+from datarobot.models.custom_model_version import RequiredMetadataValue
 from datarobot.utils import camelize
-from tests.model.utils import assert_custom_model_version
+from tests.model.utils import assert_custom_model_version, fields_to_dict
 
 
 @pytest.fixture
@@ -153,12 +155,33 @@ def test_download(mocked_version, make_versions_url, tmpdir):
 
 
 @responses.activate
-def test_update(mocked_custom_model_version_with_required_metadata, make_versions_url):
+@pytest.mark.parametrize("use_deprecated_metadata", [True, False])
+def test_update(
+    mocked_custom_model_version_with_required_metadata, make_versions_url, use_deprecated_metadata,
+):
     mocked_version = mocked_custom_model_version_with_required_metadata
     # arrange
-    attrs = {"description": "xx", "required_metadata": {"REQUIRED_FIELD": "super important value"}}
+    attrs = {"description": "xx"}
+    if use_deprecated_metadata:
+        attrs.update({"required_metadata": {"REQUIRED_FIELD": "super important value"}})
+    else:
+        attrs.update(
+            {
+                "required_metadata_values": [
+                    RequiredMetadataValue(
+                        field_name="REQUIRED_FIELD", value="super important value"
+                    )
+                ]
+            }
+        )
     api_attrs = {camelize(k): v for k, v in attrs.items()}
 
+    if not use_deprecated_metadata:
+        api_attrs["requiredMetadataValues"] = [
+            {camelize(k): v for k, v in val.to_dict().items()}
+            for val in attrs["required_metadata_values"]
+        ]
+
     url = make_versions_url(mocked_version["customModelId"], mocked_version["id"])
     mock_get_response(url, mocked_version)
 
@@ -186,6 +209,36 @@ def test_update(mocked_custom_model_version_with_required_metadata, make_version
     assert responses.calls[1].request.body == json.dumps(api_attrs).encode()
 
 
+@responses.activate
+@pytest.mark.parametrize("required_metadata", [{}, {"a": "b"}], ids=["empty", "non-empty"])
+@pytest.mark.parametrize(
+    "required_metadata_values",
+    [[], [RequiredMetadataValue(field_name="a", value="b")]],
+    ids=["empty", "non-empty"],
+)
+def test_update_with_both_required_metadata_and_required_metadata_value_raises_error(
+    mocked_custom_model_version_with_required_metadata,
+    make_versions_url,
+    required_metadata,
+    required_metadata_values,
+):
+    mocked_version = mocked_custom_model_version_with_required_metadata
+    # arrange
+    attrs = {
+        "description": "xx",
+        "required_metadata": required_metadata,
+        "required_metadata_values": required_metadata_values,
+    }
+
+    url = make_versions_url(mocked_version["customModelId"], mocked_version["id"])
+    mock_get_response(url, mocked_version)
+
+    # act
+    version = CustomModelVersion.get(mocked_version["customModelId"], mocked_version["id"])
+    with pytest.raises(ValueError):
+        version.update(**attrs)
+
+
 @responses.activate
 def test_refresh(mocked_version, make_versions_url):
     # arrange
@@ -218,7 +271,15 @@ def test_refresh(mocked_version, make_versions_url):
         "mocked_custom_model_version_with_required_metadata",
     ],
 )
-def test_create_clean(request, mocked_fixture_name, make_versions_url, tmpdir, base_environment_id):
+@pytest.mark.parametrize("use_deprecated_metadata", [True, False])
+def test_create_clean(
+    request,
+    mocked_fixture_name,
+    make_versions_url,
+    tmpdir,
+    base_environment_id,
+    use_deprecated_metadata,
+):
     mocked_version = request.getfixturevalue(mocked_fixture_name)
 
     url = make_versions_url(mocked_version["customModelId"])
@@ -231,24 +292,86 @@ def test_create_clean(request, mocked_fixture_name, make_versions_url, tmpdir, b
         body=json.dumps(mocked_version),
     )
 
-    file = tmpdir.mkdir("sub").join("file")
+    file = tmpdir.mkdir("sub").join("file.txt")
     file.write(b"content")
     file_path = str(file)
 
-    version = CustomModelVersion.create_clean(
-        mocked_version["customModelId"],
-        base_environment_id,
-        True,
+    attrs = dict(
+        custom_model_id=mocked_version["customModelId"],
+        base_environment_id=base_environment_id,
+        is_major_update=True,
         files=[(file_path, "/d/file.txt")],
         network_egress_policy=mocked_version["networkEgressPolicy"],
         maximum_memory=mocked_version["maximumMemory"],
         replicas=mocked_version["replicas"],
-        required_metadata=mocked_version.get("requiredMetadata"),
     )
+    api_attrs = {
+        "baseEnvironmentId": [base_environment_id],
+        "isMajorUpdate": [str(True)],
+        "file": [(os.path.basename(file_path), mock.ANY)],
+        "filePath": ["/d/file.txt"],
+    }
+
+    if mocked_version["networkEgressPolicy"]:
+        api_attrs["networkEgressPolicy"] = [mocked_version["networkEgressPolicy"]]
+    if mocked_version["maximumMemory"]:
+        api_attrs["maximumMemory"] = [str(mocked_version["maximumMemory"])]
+    if mocked_version["replicas"]:
+        api_attrs["replicas"] = [str(mocked_version["replicas"])]
+
+    if mocked_version.get("requiredMetadata"):
+        if use_deprecated_metadata:
+            attrs.update({"required_metadata": mocked_version.get("requiredMetadata")})
+            api_attrs.update(
+                {"requiredMetadata": [json.dumps(mocked_version.get("requiredMetadata"))]}
+            )
+        else:
+            attrs.update(
+                {
+                    "required_metadata_values": [
+                        RequiredMetadataValue.from_server_data(val)
+                        for val in mocked_version.get("requiredMetadataValues")
+                    ]
+                }
+            )
+            api_attrs.update(
+                {
+                    "requiredMetadataValues": [
+                        json.dumps(mocked_version.get("requiredMetadataValues"))
+                    ],
+                }
+            )
+
+    version = CustomModelVersion.create_clean(**attrs)
     assert_custom_model_version(version, mocked_version)
 
     assert responses.calls[0].request.method == "POST"
     assert responses.calls[0].request.url == url
+    request_body = responses.calls[0].request.body
+    field_dict = fields_to_dict(request_body)
+    field_dict["file"] = [(path, mock.ANY) for path, _ in field_dict["file"]]
+    assert field_dict == api_attrs
+
+
+@pytest.mark.parametrize("required_metadata", [{}, {"a": "b"}], ids=["empty", "non-empty"])
+@pytest.mark.parametrize(
+    "required_metadata_values",
+    [[], [RequiredMetadataValue(field_name="a", value="b")]],
+    ids=["empty", "non-empty"],
+)
+def test_create_clean_with_both_required_metadata_and_required_metadata_value_raises_error(
+    required_metadata, required_metadata_values
+):
+    attrs = dict(
+        custom_model_id="abc123",
+        base_environment_id="dev456",
+        is_major_update=True,
+        required_metadata=required_metadata,
+        required_metadata_values=required_metadata_values,
+    )
+
+    with pytest.raises(ValueError):
+        CustomModelVersion.create_clean(**attrs)
 
 
 @responses.activate
