@@ -172,6 +172,7 @@ def predictions_multilabel_json():
                 "predictionValues": [
                     {"threshold": 0.5, "value": 0.6, "label": "cat"},
                     {"threshold": 0.5, "value": 0.5, "label": u"🐕"},
+                    {"threshold": 0.5, "value": 0.4, "label": "Maine Coon"},
                 ],
                 "prediction": ["cat"],
                 "rowId": 0,
@@ -180,6 +181,7 @@ def predictions_multilabel_json():
                 "predictionValues": [
                     {"threshold": 0.5, "value": 0.1, "label": "cat"},
                     {"threshold": 0.5, "value": 0.4, "label": u"🐕"},
+                    {"threshold": 0.5, "value": 0.4, "label": "Maine Coon"},
                 ],
                 "prediction": [],
                 "rowId": 1,
@@ -535,6 +537,9 @@ def test_get_all_as_dataframe_multilabel_json_serializer(
                 u"threshold_🐕": 0.5,
                 u"prediction_🐕": 0,
                 u"class_🐕": 0.5,
+                u"threshold_Maine Coon": 0.5,
+                u"prediction_Maine Coon": 0,
+                u"class_Maine Coon": 0.4,
             },
             {
                 u"row_id": 1,
@@ -544,6 +549,9 @@ def test_get_all_as_dataframe_multilabel_json_serializer(
                 u"threshold_🐕": 0.5,
                 u"prediction_🐕": 0,
                 u"class_🐕": 0.4,
+                u"threshold_Maine Coon": 0.5,
+                u"prediction_Maine Coon": 0,
+                u"class_Maine Coon": 0.4,
             },
         ]
     )
