@@ -2,12 +2,13 @@ import pytest
 import trafaret as t
 from trafaret import DataError
 
+from datarobot._compat import String
 from datarobot.models.api_object import APIObject
 
 
 def test_safe_data_renaming():
     class Dummy(APIObject):
-        _converter = t.Dict({t.Key("renamed") >> "magic": t.String()})
+        _converter = t.Dict({t.Key("renamed") >> "magic": String()})
 
     data = Dummy._safe_data({"renamed": "nombre"})
     assert data == {"magic": "nombre"}
@@ -30,7 +31,7 @@ def test_safe_data_renaming():
 )
 def test_safe_data_recursive(data, do_recursive, validation_success):
     class Dummy(APIObject):
-        _converter = t.Dict({t.Key("l1_prop"): t.Dict({t.Key("l2_prop"): t.String()})})
+        _converter = t.Dict({t.Key("l1_prop"): t.Dict({t.Key("l2_prop"): String()})})
 
     if validation_success:
         safe_data = Dummy._safe_data(data, do_recursive=do_recursive)
