@@ -7,6 +7,7 @@ import time
 
 import dateutil
 import mock
+import pandas as pd
 import pytest
 import responses
 import trafaret as t
@@ -499,6 +500,14 @@ def batch_prediction_job_data_csv():
 0.420107662678,0.579892337322,0.0,0.5,1.0,OK"""
 
 
+@pytest.fixture
+def batch_prediction_job_data_csv_with_index():
+    return b"""readmitted_1.0_PREDICTION,readmitted_0.0_PREDICTION,readmitted_PREDICTION,THRESHOLD,POSITIVE_CLASS,prediction_status,__DR_index__
+0.219181314111,0.780818685889,0.0,0.5,1.0,OK,0
+0.341459780931,0.658540219069,0.0,0.5,1.0,OK,1
+0.420107662678,0.579892337322,0.0,0.5,1.0,OK,2"""
+
+
 @responses.activate
 @pytest.mark.usefixtures("client")
 def test_list_batch_prediction_jobs_by_status(batch_prediction_jobs_json):
@@ -1720,6 +1729,67 @@ def test_download_read_timeout(
         )
 
 
+@pytest.mark.parametrize(
+    ["upload_kwargs", "expected_read_timeout"],
+    [
+        pytest.param({}, 600, id="default-timeout"),
+        pytest.param({"upload_read_timeout": 200}, 200, id="override-timeout"),
+    ],
+)
+@responses.activate
+def test_upload_read_timeout(
+    tmpdir,
+    batch_prediction_job_initializing_json,
+    batch_prediction_job_completed_json,
+    batch_prediction_job_data_csv,
+    upload_kwargs,
+    expected_read_timeout,
+):
+    responses.add(
+        responses.POST,
+        "https://host_name.com/batchPredictions/",
+        body=batch_prediction_job_initializing_json,
+        headers={"Location": "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/"},
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/",
+        body=batch_prediction_job_completed_json,
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/download/",
+        body=batch_prediction_job_data_csv,
+    )
+
+    upload_file = io.BytesIO(b"foo\nbar")
+    thread_count_before = threading.activeCount()
+
+    with mock.patch.object(
+        BatchPredictionJob._client, "copy", wraps=BatchPredictionJob._client.copy
+    ) as upload_spy:
+        upload_client = mock.MagicMock(connect_timeout=6.05)
+        upload_spy.return_value = upload_client
+
+        BatchPredictionJob.score_to_file(
+            "5ce1138c962d7415e076d8c6",
+            upload_file,
+            str(tmpdir.mkdir("sub").join("scored.csv")),
+            **upload_kwargs
+        )
+
+        upload_client.put.assert_any_call(
+            url="https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/csvUpload/",
+            data=upload_file,
+            headers={"content-type": "text/csv"},
+            timeout=(6.05, expected_read_timeout),
+        )
+
+    assert thread_count_before == threading.activeCount(), "Thread leak"
+
+
 @responses.activate
 def test_exception_during_cleanup(batch_prediction_job_initializing_json):
 
@@ -1740,3 +1810,56 @@ def test_exception_during_cleanup(batch_prediction_job_initializing_json):
 
     with pytest.raises(RuntimeError, match=r"Timed out waiting for download to become available"):
         job.download(io.BytesIO(), timeout=1)
+
+
+@responses.activate
+@pytest.mark.usefixtures("client")
+def test_score_pandas(
+    batch_prediction_job_initializing_json,
+    batch_prediction_job_completed_json,
+    batch_prediction_job_data_csv_with_index,
+):
+
+    responses.add(
+        responses.POST,
+        "https://host_name.com/batchPredictions/",
+        body=batch_prediction_job_initializing_json,
+        headers={"Location": "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/"},
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/download/",
+        body=batch_prediction_job_data_csv_with_index,
+        stream=True,
+    )
+
+    responses.add(
+        responses.PUT,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/csvUpload/",
+        body="",
+        status=202,
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/",
+        body=batch_prediction_job_completed_json,
+    )
+
+    df = pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
+
+    job, df = BatchPredictionJob.score_pandas("5ce1138c962d7415e076d8c6", df)
+
+    assert df.shape == (3, 8)
+
+    assert set(df.columns) == {
+        "a",
+        "b",
+        "readmitted_1.0_PREDICTION",
+        "readmitted_0.0_PREDICTION",
+        "readmitted_PREDICTION",
+        "THRESHOLD",
+        "POSITIVE_CLASS",
+        "prediction_status",
+    }
