@@ -462,6 +462,8 @@ class TestClientAttributes(unittest.TestCase):
             "CustomModelVersion",
             "CustomModelVersionDependencyBuild",
             "CustomModelTest",
+            "CustomTask",
+            "CustomTaskVersion",
             "FeatureImpactJob",
             "RelationshipsConfiguration",
             "NETWORK_EGRESS_POLICY",
@@ -473,7 +475,9 @@ class TestClientAttributes(unittest.TestCase):
             "feature_discovery",
             "SecondaryDataset",
             "Relationship",
+            "FeatureDiscoverySetting",
             "SNAPSHOT_POLICY",
+            "UserBlueprint",
         }
 
         found_names = {name for name in dir(dr) if not name.startswith("_")}
