@@ -87,7 +87,7 @@ def test_from_data_with_datetime(datetime_model_data):
 
 def test_get_permalink_for_model(one_model):
     """
-    Model(('p-id', 'l-id')).get_leaderboard_ui_permalink()
+    Model(('project-id', 'model-id')).get_leaderboard_ui_permalink()
     """
     expected_link = (
         "https://host_name.com/projects/556cdfbb100d2b0e88585195/models/556ce973100d2b6e51ca9657"
@@ -102,10 +102,15 @@ def test_open_model_browser(webbrowser_open, one_model):
 
 
 @responses.activate
-def test_model_item_get(model_json, model_id, model_url, project_id):
+def test_model_item_get(
+    model_json, model_id, model_url, project_id, project_url, project_with_target_json
+):
     """
-    Test Model.get(project_instance, 'l-id')
+    Test Model.get(project_instance, 'model-id')
     """
+    responses.add(
+        responses.GET, project_url, body=project_with_target_json, status=200,
+    )
     responses.add(
         responses.GET, model_url, body=model_json, status=200, content_type="application/json"
     )
@@ -169,7 +174,12 @@ def test_model_get_using_project_instance(model_json, project, model_url, model_
 
 
 @responses.activate
-def test_model_item_get_with_project_id(model_json, model_id, project_id, model_url):
+def test_model_item_get_with_project_id(
+    model_json, model_id, project_id, model_url, project_url, project_with_target_json
+):
+    responses.add(
+        responses.GET, project_url, body=project_with_target_json, status=200,
+    )
     responses.add(
         responses.GET, model_url, body=model_json, status=200, content_type="application/json"
     )
@@ -218,7 +228,7 @@ def test_toggle_starred_unchanged_on_failed(project_id, one_model):
 def test_get_num_iterations_trained(one_model, project_id, model_id):
     """
     Test get number of iterations run for early stopping model
-    Model('p-id', 'l-id').get_num_iterations_trained()
+    Model('project-id', 'model-id').get_num_iterations_trained()
     """
     url = "https://host_name.com/projects/{}/models/{}/numIterationsTrained/".format(
         project_id, model_id
@@ -251,7 +261,7 @@ def test_get_num_iterations_trained(one_model, project_id, model_id):
 def test_model_supported_capabilities(one_model, project_id, model_id):
     """
     Test get supported capabilities for a model
-    Model('p-id', 'l-id').get_supported_capabilities()
+    Model('project-id', 'model-id').get_supported_capabilities()
     """
     url = "https://host_name.com/projects/{}/models/{}/supportedCapabilities/".format(
         project_id, model_id
@@ -291,7 +301,7 @@ def test_model_supported_capabilities(one_model, project_id, model_id):
 def test_model_delete(one_model, model_url):
     """
     Test delete model
-    Model('p-id', 'l-id').delete()
+    Model('project-id', 'model-id').delete()
     """
     responses.add(responses.DELETE, model_url, status=204)
 
@@ -309,7 +319,7 @@ def model_features_url(project_id, model_id):
 def test_model_features(one_model, model_features_url):
     """
     Test get names of features used in model
-    Model('p-id', 'l-id').get_features_used()
+    Model('project-id', 'model-id').get_features_used()
     """
     body = json.dumps({"featureNames": ["apple", "banana", "cherry"]})
 
@@ -1756,7 +1766,12 @@ def test_get_frozen_child_models(project_id, model_data, frozen_models_list_resp
 
 
 @responses.activate
-def test_frozen_model_parent_id(frozen_json, model_id, model_url, project_id):
+def test_frozen_model_parent_id(
+    frozen_json, model_id, model_url, project_id, project_url, project_with_target_json
+):
+    responses.add(
+        responses.GET, project_url, body=project_with_target_json, status=200,
+    )
     responses.add(
         responses.GET, model_url, body=frozen_json, status=200, content_type="application/json"
     )
